import { Injectable } from '@angular/core';

@Injectable({
  providedIn: 'root',
})
export class SpeciesService {
  constructor() {}

  public getSpeciesDetails(name: string): any {
    switch (name) {
      case 'dwarf':
        return this.dwarf;
      case 'elf':
        return this.elf;
      case 'gnome':
        return this.gnome;
      case 'halfElf':
        return this.halfElf;
      case 'halfling':
        return this.halfling;
      case 'halfOrc':
        return this.halfOrc;
      case 'human':
        return this.human;
      case 'dragonborn':
        return this.dragonborn;
      case 'tiefling':
        return this.tiefling;
      case 'eladrin':
        return this.eladrin;
      case 'halfElfDetection':
        return this.halfElfDetection;
      default:
        return this.notImplementedYet;
    }
  }

  // Common Species

  private dwarf: any = {
    title: 'dwarf',
    content: [
      {
        title: "Player's Handbook",
        description: `
        <p><strong><em>Kingdoms rich in ancient grandeur, halls carved into the roots of mountains, the echoing of picks and hammers in deep mines and blazing forges, a commitment to clan and tradition, and a burning hatred of goblins and orcs –&nbsp;these common threads unite all dwarves.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Constitution score increases by 2.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Dwarves mature at the same rate as humans, but they're considered young until they reach the age of 50. On average, they live about 350 years.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Most dwarves are lawful, believing firmly in the benefits of a well-ordered society. They tend toward good as well, with a strong sense of fair play and a belief that everyone deserves to share in the benefits of a just order.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Dwarves stand between 4 and 5 feet tall and average about 150 pounds. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 25 feet. Your speed is not reduced by wearing heavy armor.</li>
          </ul>
          <ul>
          <li><strong>Dwarven Combat Training.</strong> You have proficiency with the battleaxe, handaxe, light hammer, and warhammer.</li>
          </ul>
          <ul>
          <li><strong>Tool Proficiency.</strong> You gain proficiency with the artisan's tools of your choice: smith's tools, brewer's supplies, or mason's tools.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Dwarvish. Dwarvish is full of hard consonants and guttural sounds, and those characteristics spill over into whatever other language a dwarf might speak.</li>
          </ul>
      `,
        features: [
          {
            name: 'Dwarven Resilience',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws against poison, and you have resistance against poison damage.</p>
            `,
          },
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Accustomed to life underground, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
          {
            name: 'Stonecunning',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make an Intelligence (History) check related to the origin of stonework, you are considered proficient in the History skill and add double your proficiency bonus to the check, instead of your normal proficiency bonus.</p>
            `,
          },
        ],
      },
      {
        title: 'Hill Dwarf',
        description: `
          <p><strong><em>As a hill dwarf, you have keen senses, deep intuition, and remarkable resilience. The gold dwarves of Faerun in their mighty southern kingdom are hill dwarves, as are the exiled Neidar and the debased Klar of Krynn in the Dragonlance setting.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Dwarven Toughness.</strong> Your hit point maximum increases by 1, and it increases by 1 every time you gain a level.</li>
          </ul>
            `,
      },
      {
        title: 'Mountain Dwarf',
        description: `
          <p><strong><em>As a mountain dwarf, you're strong and hardy, accustomed to a difficult life in rugged terrain. You're probably on the tall side (for a dwarf), and tend toward lighter coloration, The shield dwarves of northern Faerun, as well as the ruling Hylar clan and the noble Daewar c1an of Dragonlance, are mountain dwarves.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Strength score increases by 2.</li>
          </ul>
          <ul>
          <li><strong>Dwarven Armor Training.</strong> You have proficiency with light and medium armor.</li>
          </ul>`,
      },
      {
        title: 'Mark of Warding',
        description: `
          <p><strong><em>If you're a dwarf with the Mark of Warding, you have this subrace, with the following traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 1</li>
          </ul>
          <ul>
          <li><strong>Wards and Seals.</strong> You can cast the Alarm and Mage Armor spells with this trait. Starting at 3rd level, you can also cast the Arcane Lock spell with it. Once you cast either spell with this trait, you can't cast that spell again until you finish a Long Rest. Intelligence is your Spellcasting Ability for these spells, and you don't require material components when you cast them with this trait.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Warding Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Warding Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td>Alarm, Armor of Agathys</td>
          </tr>
          <tr>
          <td>2nd</td>
          <td>Arcane Lock, Knock</td>
          </tr>
          <tr>
          <td>3rd</td>
          <td>Glyph of Warding, Magic Circle</td>
          </tr>
          <tr>
          <td>4th</td>
          <td>Leomund's Secret Chest, Mordenkainen's Faithful Hound</td>
          </tr>
          <tr>
          <td>5th</td>
          <td>Antilife Shell</td>
          </tr>
          </table>
            `,
        features: [
          {
            name: "Warder's Intuition",
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make an Intelligence (Investigation) check or an Ability Check involving Thieves' Tools, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
      {
        title: 'Kaladesh',
        description: `
          <p><strong><em>Dwarves don’t understand laziness or shortcuts. Just as a machine must function smoothly at all times, so too an artisan should work steadily and with care. Dwarves take pride in their work ethic, and abhor any attitude or behavior that would undermine the quality of their work. They are more thorough than speedy, and although a dwarf’s work might take longer to complete, its quality makes the time worthwhile. If a job must be done, a dwarf will see that it is done correctly. And when a dwarf repairs a machine, it will work as well as it did when it was first built, if not better — and it will last.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Constitution score increases by 2, and your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Dwarves mature at the same rate as humans, but they're considered young until they reach the age of 50. On average, they live about 350 years.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Most dwarves are lawful, believing firmly in the benefits of a well-ordered society. They tend toward good as well, with a strong sense of fair play and a belief that everyone deserves to share in the benefits of a just order.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Dwarves stand around 5 feet tall and average about 150 pounds. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 25 feet. Your speed is not reduced by wearing heavy armor.</li>
          </ul>
          <ul>
          <li><strong>Darkvision.</strong> Accustomed to life underground in your race’s ancient past, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can’t discern color in darkness, only shades of gray.</li>
          </ul>
          <ul>
          <li><strong>Dwarven Resilience.</strong> You have advantage on saving throws against poison, and you have resistance against poison damage.</li>
          </ul>
          <ul>
          <li><strong>Dwarven Toughness.</strong> Your hit point maximum increases by 1, and it increases by 1 every time you gain a level.</li>
          </ul>
          <ul>
          <li><strong>Artisan's Expertise.</strong> You gain proficiency with two kinds of artisan’s tools of your choice. Your proficiency bonus is doubled for any ability check you make that uses either of the chosen proficiencies. In addition, whenever you make an Intelligence (History) check related to the origin of any architectural construction (including buildings, public works such as canals and aqueducts, and the massive cogwork that underlies much of the construction of Ghirapur), you are considered proficient in the History skill and add double your proficiency bonus to the check, instead of your normal proficiency bonus.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Dwarvish. Dwarvish is full of hard consonants and guttural sounds, and those characteristics spill over into whatever other language a dwarf might</li>
          </ul>`,
        features: [
          {
            name: 'Dwarven Resilience',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws against poison, and you have resistance against poison damage.</p>
            `,
          },
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Accustomed to life underground, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
        ],
      },
    ],
  };

  private elf: any = {
    title: 'elf',
    content: [
      {
        title: "Player's Handbook",
        description: `
          <p><strong><em>Elves are a magical people of otherworldly grace, living in places of ethereal beauty, in the midst of ancient forests or in silvery spires glittering with faerie light, where soft music drifts through the air and gentle fragrances waft on the breeze. Elves love nature and magic, art and artistry, music and poetry.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity score increases by 2.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Although elves reach physical maturity at about the same age as humans, the elven understanding of adulthood goes beyond physical growth to encompass worldly experience. An elf typically claims adulthood and an adult name around the age of 100 and can live to be 750 years old.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Elves love freedom, variety, and self-expression, so they lean strongly towards the gentler aspects of chaos. They value and protect others' freedom as well as their own, and are good more often than not. Drow are an exception; their exile into the Underdark has made them vicious and dangerous. Drow are more often evil than not.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Elves range from under 5 to over 6 feet tall and have slender builds. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Keen Senses.</strong> You have proficiency in the Perception skill.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Elven.</li>
          </ul>
        `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Accustomed to twilit forests and the night sky, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
          {
            name: 'Fey Ancestry',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws against being charmed, and magic can't put you to sleep.</p>
            `,
          },
          {
            name: 'Trance',
            level: 0,
            isAbility: false,
            description: `
            <p>Elves do not sleep. Instead they meditate deeply, remaining semi-conscious, for 4 hours a day. The Common word for this meditation is &quot;trance.&quot; While meditating, you dream after a fashion; such dreams are actually mental exercises that have become reflexive after years of practice. After resting in this way, you gain the same benefit a human would from 8 hours of sleep.</p>
            `,
          },
        ],
      },

      {
        title: 'Dark Elf',
        description: `
          <p><strong><em>Descended from an earlier subrace of dark-skinned elves, the drow were banished from the surface world for following the goddess Lolth down the path to evil and corruption. Now they have built their own civilization in the depths of the Underdark, patterned after the Way of Lolth. Also called dark elves. The drow have black skin that resembles polished obsidian and stark white or pale yellow hair. They commonly have very pale eyes (so pale as to be mistaken for white) in shades of lilac, silver, pink, red, and blue. They lend to be smaller and thinner than most elves.</em></strong></p>
          <p><strong><em>Drow adventurers are rare, and the race does not exist in all worlds. Check with your Dungeon Master to see if you can play a drow character.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Drow Magic.</strong> You know the Dancing Lights cantrip. When you reach 3rd level, you can cast the Faerie Fire spell once with this trait and regain the ability to do so when you finish a long rest. When you reach 5th level, you can cast the Darkness spell once and regain the ability to do so when you finish a long rest. Charisma is your spellcasting ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Drow Weapon Training.</strong> You have proficiency with rapiers, shortswords, and hand crossbows.</li>
          </ul>
        `,
        features: [
          {
            name: 'Superior Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Your darkvision has a range of 120 feet, instead of 60.</p>
            `,
          },
          {
            name: 'Sunlight Sensitivity',
            level: 0,
            isAbility: false,
            description: `
            <p>You have disadvantage on attack rolls and Wisdom (Perception) checks that rely on sight when you, the target of the attack, or whatever you are trying to perceive is in direct sunlight.</p>
            `,
          },
        ],
      },
      {
        title: 'High Elf',
        description: `
          <p><strong><em>As a high elf, you have a keen mind and a mastery of at least the basics of magic. In many of the worlds of D&amp;D, there are two kinds of high elves. One type (which includes the gray elves and valley elves of Greyhawk, the Silvanesti of Dragonlance, and the sun elves of the Forgotten Realms) is haughty and reclusive, believing themselves to be superior to non-elves and even other elves. The other type (including the high elves of Greyhawk. the Qualinesti of Dragonlance, and the moon elves of the Forgotten Realms) are more common and more friendly, and often encountered among humans and other races.</em></strong></p>
          <p><strong><em>The sun elves of Faerun (also called gold elves or sunrise elves) have bronze skin and hair of copper, black, or golden blood. Their eyes are golden, silver, or black. Moon elves (also called silver elves or gray elves) are much paler, with alabaster skin sometimes tinged with blue. They often have hair of silver-while, black, or blue, but various shades of blond, brown, and red are not uncommon. Their eyes are blue or green and flecked with gold.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Cantrip.</strong> You know one cantrip of your choice from the Wizard spell list. Intelligence is your spellcasting ability for it.</li>
          </ul>
          <ul>
          <li><strong>Elf Weapon Training.</strong> You have proficiency with the longsword, shortsword, shortbow, and longbow.</li>
          </ul>
          <ul>
          <li><strong>Extra Language.</strong> You can read, speak, and write one additional language of your choice.</li>
          </ul>
        `,
      },
      {
        title: 'Wood Elf',
        description: `
          <p><strong><em>As a wood elf, you have keen senses and intuition, and your fleet feet carry you quickly and stealthily through your native forests. This category includes the wild elves (grugach) of Greyhawk and the Kagonesti of Dragonlance, as well as the races called wood elves in Greyhawk and the Forgotten Realms. In Faerun, wood elves (also called wild elves. green elves, or forest elves) are reclusive and distrusting of non-elves.</em></strong></p>
          <p><strong><em>Wood elves' skin tends to be copperish in hue, sometimes with traces of green. Their hair tends toward browns and blacks, but it is occasionally blond or copper-colored. Their eyes are green, brown, or hazel.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Elf Weapon Training.</strong> You have proficiency with the longsword, shortsword, shortbow, and longbow.</li>
          </ul>
          <ul>
          <li><strong>Fleet of Foot.</strong> Your base walking speed increases to 35 feet.</li>
          </ul>
        `,
        features: [
          {
            name: 'Mask of the Wild',
            level: 0,
            isAbility: false,
            description: `
            <p>You can attempt to hide even when you are only lightly obscured by foliage, heavy rain, falling snow, mist, and other natural phenomena.</p>
            `,
          },
        ],
      },
      {
        title: 'Pallid Elf',
        description: `
          <p><strong><em>The pallid elves are a mystical and insightful people with skin as pale as the surface of Exandria's largest moon. They emerged from the Pallid Grove this century and wander the world with childlike curiosity.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Blessing of the Moonweaver.</strong> You know the Light cantrip. When you reach 3rd level, you can cast Sleep once, and it recharges after a long rest. When you reach 5th level, you can cast Invisibility (Self Only) once, and it recharges after a long rest. You do not need the material components required of the spells. Wisdom is your spellcasting ability for these spells.</li>
          </ul>
        `,
        features: [
          {
            name: 'Incisive Sense',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on Investigation and Insight checks.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Shadow',
        description: `
          <p><strong><em>If you're an elf with the Mark of Shadow, you have this subrace, with the following traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 1</li>
          </ul>
          <ul>
          <li><strong>Shape Shadows.</strong> You know the Minor Illusion cantrip. Starting at 3rd level, you can also cast the Invisibility spell with this trait. Once you cast either spell with this trait, you can't cast that spell again until you finish a long rest. Charisma is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class features, the spells on the Mark of Shadow Spells table are added to the spell list of your spellcasting class.</li>
          </ul>
          <p><strong>Mark of Shadow Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td>Disguise Self, Silent Image</td>
          </tr>
          <tr>
          <td>2nd</td>
          <td>Darkness, Pass Without Trace</td>
          </tr>
          <tr>
          <td>3rd</td>
          <td>Clairvoyance,Major Image</td>
          </tr>
          <tr>
          <td>4th</td>
          <td>Greater Invisibility, Hallucinatory Terrain</td>
          </tr>
          <tr>
          <td>5th</td>
          <td>Mislead</td>
          </tr>
          </table>
        `,
        features: [
          {
            name: 'Cunning Intuition',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you roll a Dexterity (Stealth) check or a Charisma (Performance) check, roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
      {
        title: 'Astral Elf',
        description: `
          <p>Source: Astral Adventurer's Guide</p>
          <p><strong><em>Long ago, groups of elves ventured from the Feywild to the Astral Plane to be closer to their gods. Life in the Silver Void has imbued their souls with a spark of divine light. That light manifests as a starry gleam in an astral elf's eyes.</em></strong></p>
          <p><strong><em>Because nothing ages on the Astral Plane, astral elves who inhabit that plane can be very old, and their longevity gives them an unusual perspective on the passage of time. Some are prone to melancholy, while others might display an absence of feeling. Many look for creative ways to occupy themselves. Whether they choose to live in quiet contemplation or strike out to explore the reaches of the multiverse, astral elves tend to see things through the lens of time as having little or no meaning to them. Astral elves who don't dwell in the Astral Plane can live to be more than 750 years old.</em></strong></p>
          <ul>
          <li><em><strong>Ability Score Increase.</strong></em> Increase one ability score by 2, and increase a different one by 1, or increase three different scores by 1.</li>
          </ul>
          <ul>
          <li><em><strong>Creature Type.</strong></em> You are a Humanoid. You are also considered an elf for any prerequisite or effect that requires you to be an elf.</li>
          </ul>
          <ul>
          <li><em><strong>Size.</strong></em> You are Medium.</li>
          </ul>
          <ul>
          <li><em><strong>Speed.</strong></em> Your walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><em><strong>Astral Fire.</strong></em> You know one of the following cantrips of your choice: Dancing Lights, Light, or Sacred Flame. Intelligence, Wisdom, or Charisma is your spellcasting ability for it (choose when you select this race).</li>
          </ul>       
          <ul>
          <li><em><strong>Keen Senses.</strong></em> You have proficiency in the Perception skill.</li>
          </ul>
          <ul>
          <li><em><strong>Languages.</strong></em> You can speak, read, and write Common and one other language that you and your DM agree is appropriate.</li>
          </ul>
        `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see dim light within 60 feet of yourself as if it were bright light, and in darkness as if it were dim light. You discern colors in darkness only as shades of gray.</p>
            `,
          },
          {
            name: 'Fey Ancestry',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws you make to avoid or end the charmed condition on yourself.</p>
            `,
          },
          {
            name: 'Starlight Step',
            level: 0,
            isAbility: true,
            description: `
            <p>As a bonus action, you can magically teleport up to 30 feet to an unoccupied space you can see. You can use this trait a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
            `,
          },
          {
            name: 'Astral Trance',
            level: 0,
            isAbility: false,
            description: `
            <p>You don't need to sleep, and magic can't put you to sleep. You can finish a long rest in 4 hours if you spend those hours in a trancelike meditation, during which you remain conscious. Whenever you finish this trance, you gain proficiency in one skill of your choice and with one weapon or tool of your choice, selected from the <em>Player's Handbook</em>. You magically acquire these proficiencies by drawing them from shared elven memory and the experiences of entities on the Astral Plane, and you retain them until you finish your next long rest.</p>
            `,
          },
        ],
      },
      {
        title: 'Bishtahar/Tirahar Elves',
        description: `
          <p><strong><em>Elves who dwell in the forest and countryside are known as the Bishtahar. Most live in isolated communities away from other races, though they still trade with them. In fact, much of Kaladesh’s food supply is grown by elves. Bishtahar cultivators grow food, decorative flowers, wood for building, and elaborate living sculptures in their meandering gardens and fields. They use the plane’s ubiquitous technology to foster the growth of plants and animals, utilizing automatons as gardeners and herders, and employing elaborate, nearly invisible systems controlling heat, water, and nutrients.</em></strong></p>
          <p><strong><em>Elves who forsake technology entirely are called the Tirahar. Some elves with Tirahar sympathies live within cities or farms, but most simply withdraw to the wilder areas of Kaladesh. No more than one in a hundred elves is counted among the Tirahar, and many members of other races are unaware that these reclusive elves even exist.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Elf Weapon Training.</strong> You have proficiency with the longsword, shortsword, shortbow, and longbow.</li>
          </ul>
          <ul>
          <li><strong>Fleet of Foot.</strong> Your base walking speed increases to 35 feet.</li>
          </ul>
        `,
        features: [
          {
            name: 'Mask of the Wild',
            level: 0,
            isAbility: false,
            description: `
            <p>You can attempt to hide even when you are only lightly obscured by foliage, heavy rain, falling snow, mist, and other natural phenomena.</p>
            `,
          },
        ],
      },
      {
        title: 'Vahadar Elf',
        description: `
          <p><strong><em>The Vahadar are elves who dwell in the cities of Kaladesh. They are comfortable with technology, and work as planners, architects, aether-seers, or inventors. Some of them use the techniques of Bishtahar cultivators to grow food on rooftops, towers, and greenways. The Vahadar are generally integrated into the rest of society on Kaladesh, living in cities dominated by the other races (though, as in Ghirapur, many of them live in specific garden-like neighborhoods) and engaging in trade.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Elf Weapon Training.</strong> You have proficiency with the longsword, shortsword, shortbow, and longbow.</li>
          </ul>
          <ul>
          <li><strong>Cantrip.</strong> You know one cantrip of your choice from the Druid spell list. Wisdom is your spellcasting ability for it.</li>
          </ul>
          <ul>
          <li><strong>Extra Language.</strong> You can speak, read, and write one extra language of your choice.</li>
          </ul>
        `,
      },
      {
        title: 'Zendikar Elf',
        description: `
          <p><strong><em>Elves are strongly associated with nature, the magic that flows through their forest homes. Their shamans and druids channel this magic of life and growth, communing with the land or the spirits of the departed. Striving to live in harmony with nature, they celebrate the ties between their communities and their connection with the broader world around them.</em></strong></p>
          <p><strong><em>The elves of Zendikar have much in common with the elves of other worlds. Your elf character has the following traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 2.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Although elves reach physical maturity at about the same age as humans, the elven understanding of adulthood goes beyond physical growth to encompass worldly experience. An elf typically claims adulthood and an adult name around the age of 100 and can live to be 750 years old.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Elves love freedom, variety, and self-expression, so they lean strongly towards the gentler aspects of chaos. They value and protect others' freedom as well as their own, and are good more often than not. Drow are an exception; their exile into the Underdark has made them vicious and dangerous. Drow are more often evil than not.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Elves range from under 5 to over 6 feet tall and have slender builds. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Keen Senses.</strong> You have proficiency in the Perception skill.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Elven.</li>
          </ul>
        `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Accustomed to twilit forests and the night sky, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
          {
            name: 'Fey Ancestry',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws against being charmed, and magic can't put you to sleep.</p>
            `,
          },
          {
            name: 'Trance',
            level: 0,
            isAbility: false,
            description: `
            <p>Elves do not sleep. Instead they meditate deeply, remaining semi-conscious, for 4 hours a day. The Common word for this meditation is &quot;trance.&quot; While meditating, you dream after a fashion; such dreams are actually mental exercises that have become reflexive after years of practice. After resting in this way, you gain the same benefit a human would from 8 hours of sleep.</p>
            `,
          },
        ],
      },
      {
        title: 'Tajuru Elf',
        description: `
          <p><strong><em>The Tajuru nation is the largest of the three main elven nations, concentrated in Murasa and spread across other parts of Zendikar as hundreds of far-flung clans. Tajuru elves are the most open to people of other races, seeing their skills and perspectives as valuable new tools for survival. The Tajuru are also more open to new lifestyles, be it living in a mountaintop citadel or roaming grassy plains.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Skill Versatility.</strong> You gain proficiency in any combination of two skills or tools of your choice.</li>
          </ul>
        `,
      },
      {
        title: 'Juraga Elf',
        description: `
          <p><strong><em>The elves of the imperious Joraga nation of Bala Ged have little respect for any other race of Zendikar — or even for other elves. The survival of their nation and its traditions is the Joraga elves’ only goal, and they view the influence of others as a weakness. The Joraga eschew the goods and habits of others, even avoiding the pathways blazed by the Tajuru when possible. Many view the nomadic Joraga clans as little more than bands of roving murderers, but a complex culture hides behind those clans’ aggressive exterior.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Elf Weapon Training.</strong> You have proficiency with the longsword, shortsword, shortbow, and longbow.</li>
          </ul>
          <ul>
          <li><strong>Fleet of Foot.</strong> Your base walking speed increases to 35 feet.</li>
          </ul>
      `,
        features: [
          {
            name: 'Mask of the Wild',
            level: 0,
            isAbility: false,
            description: `
            <p>You can attempt to hide even when you are only lightly obscured by foliage, heavy rain, falling snow, mist, and other natural phenomena.</p>
            `,
          },
        ],
      },
      {
        title: 'Mul Daya',
        description: `
          <p><strong><em>Elves of the Mul Daya nation of Bala Ged are set apart from other elves by their relationship with the spirits of their elven ancestors. To the Mul Daya, the spirit world and the mortal realm are different only in terms of their tangibility. Death and the spirits of the dead are as much a part of the lives of the Mul Daya as is the natural world. This is not a macabre sentiment to the elves; they simply view it as the truest sense of the natural order.</em></strong></p>
          <p><strong><em>Mul Daya elves can often be recognized by their face painting and tattooing. Many Mul Daya decorate their skins with an enwrapping vine motif, and make use of poisons and acids collected at great cost from strange creatures and plants in the depths of Kazandu.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Strength score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Mul Daya Magic.</strong> You know the chill touch cantrip. When you reach 3rd level, you can cast the hex spell once with this trait and regain the ability to do so when you finish a long rest. When you reach 5th level, you can cast the darkness spell once with this trait and regain the ability to do so when you finish a long rest. Wisdom is your spellcasting ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Elf Weapon Training.</strong> You have proficiency with the longsword, shortsword, shortbow, and longbow.</li>
          </ul>
        `,
        features: [
          {
            name: 'Superior Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Your darkvision has a radius of 120 feet.</p>
            `,
          },
          {
            name: 'Sunlight Sensitivity',
            level: 0,
            isAbility: false,
            description: `
            <p>You have disadvantage on attack rolls and on Wisdom (Perception) checks that rely on sight when you, the target of your attack, or whatever you are trying to perceive is in direct sunlight.</p>
            `,
          },
        ],
      },
      {
        title: 'Avariel Elf',
        description: `
          <p>Source: Unearthed Arcana 46 - Elf Subraces</p>
          <p><strong><em>The avariel are winged elves. These rare creatures were more common when the worlds of the multiverse were young, but frequent conflicts with dragons much reduced the winged elves’ number. Still, a few colonies persist here and there in the Material Plane and on the Plane of Air.</em></strong></p>
          <ul>
          <li><strong>Flight.</strong> You have a flying speed of 30 feet. To use this speed, you can't be wearing medium or heavy armor.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Auran.</li>
          </ul>
        `,
      },
      {
        title: 'Gurgach Elf',
        description: `
          <p><strong><em>The grugach of the world of Greyhawk shun contact with other folk, preferring the solace of the deepest forests and the companionship of wild animals. Even other elves draw their suspicion.</em></strong></p>
          <p><strong><em>The grugach tend toward chaos and neutrality. They feel no special duty to anyone beyond their own folk and the forest that is their home. Troubles beyond their borders are best kept there. At the same time, they harbor little ambition beyond a peaceful coexistence with nature.</em></strong></p>
          <p><strong><em>If anyone is fool enough to disturb a grugach realm, these elves take to arms and fight in earnest. Grugach master the basic weapons needed to hunt and forage in the wood. Every copse of trees becomes a sniper's nest, and each forest meadow is an ambush point. The grugach set pits filled with stakes, snares that leave an intruder helpless to grugach arrows, and other snares designed to kill rather than capture. The grugach fight to the death to preserve their realms.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Strength score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Grugach Weapon Training.</strong> You have proficiency with the spear, shortbow, longbow, and net.</li>
          </ul>
          <ul>
          <li><strong>Cantrip.</strong> You know one cantrip of your choice from the Druid spell list. Wisdom is your spellcasting ability for it.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> Unlike other elves, you don't speak, read, or write Common. You instead speak, read, and write Sylvan.</li>
          </ul>
        `,
      },
    ],
  };

  private gnome: any = {
    title: 'gnome',
    content: [
      {
        title: "Player's Handbook",
        description: `
        <p><strong><em>A constant hum of busy activity pervades the warrens and neighborhoods where gnomes form their close-knit communities. Louder sounds punctuate the hum: a crunch of grinding gears here, a minor explosion there, a yelp of surprise or triumph, and especially bursts of laughter. Gnomes take delight in life, enjoying every moment of invention, exploration, investigation, creation, and play.</em></strong></p>
        <ul>
        <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 2.</li>
        </ul>
        <ul>
        <li><strong>Age.</strong> Gnomes mature at the same rate as humans, and most are expected to settle into adult life around the age of 40. They can live to 350 years on average, but it's not too uncommon for them to reach 500 years of age.</li>
        </ul>
        <ul>
        <li><strong>Alignment.</strong> Gnomes are generally Good. Those who tend towards Law are sages, engineers, researchers, scholars, investigators, or inventors. Those who tend towards Chaos are often minstrels, tricksters, wanderers, or fanciful jewelers. Gnomes are light-hearted, and even the tricksters amongst them favor harmless pranks over vicious schemes.</li>
        </ul>
        <ul>
        <li><strong>Size.</strong> Gnomes are between 3 and 4 feet tall and weigh around 40 pounds. Your size is Small.</li>
        </ul>
        <ul>
        <li><strong>Speed.</strong> Your base walking speed is 25 feet.</li>
        </ul>
        <ul>
        <li><strong>Languages.</strong> You can read, speak, and write Common and Gnomish.</li>
        </ul>
      `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Accustomed to life underground, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
          {
            name: 'Gnome Cunning',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on all Intelligence, Wisdom, and Charisma saves against magic.</p>
            `,
          },
        ],
      },
      {
        title: 'Forest Gnome',
        description: `
          <p><strong><em>As a forest gnome, you have a natural knack for illusion and inherent quickness and stealth. In the worlds of D&amp;D, forest gnomes are rare and secretive. They gather in hidden communities in sylvan forests, using illusions and trickery to conceal themselves from threats or to mask their escape should they be detected. Forest gnomes tend to be friendly with other good-spirited woodland folk, and they regard elves and good fey as their most important allies. These gnomes also befriend small forest animals and rely on them for information about threats that might prowl their lands.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Natural Illusionist.</strong> You know the Minor Illusion cantrip. Intelligence is your spellcasting modifier for it.</li>
          </ul>
        `,
        features: [
          {
            name: 'Speak with Small Beasts',
            level: 0,
            isAbility: false,
            description: `
            <p>Through sound and gestures, you may communicate simple ideas with Small or smaller beasts.</p>
            `,
          },
        ],
      },
      {
        title: 'Rock Gnome',
        description: `
          <p><strong><em>As a rock gnome, you have a natural inventiveness and hardiness beyond that of other gnomes. Most gnomes in the worlds of D&amp;D are rock gnomes, including the tinker gnomes of the Dragonlance setting.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Constitution score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Artificer's Lore.</strong> Whenever you make an Intelligence (History) check related to magical, alchemical, or technological items, you can add twice your proficiency bonus instead of any other proficiency bonus that may apply.</li>
          </ul>
          <ul>
          <li><strong>Tinker.</strong> You have proficiency with artisan tools (tinker's tools). Using those tools, you can spend 1 hour and 10 gp worth of materials to construct a Tiny clockwork device (AC 5, 1 hp). The device ceases to function after 24 hours (unless you spend 1 hour repairing it to keep the device functioning), or when you use your action to dismantle it; at that time, you can reclaim the materials used to create it. You can have up to three such devices active at a time. When you create a device, choose one of the following options:
          <ul>
          <li><em><strong>Clockwork Toy.</strong></em> This toy is a clockwork animal, monster, or person, such as a frog, mouse, bird, dragon, or soldier. When placed on the ground, the toy moves 5 feet across the ground on each of your turns in a random direction. It makes noises as appropriate to the creature it represents.</li>
          <li><em><strong>Fire Starter.</strong></em> The device produces a miniature flame, which you can use to light a candle, torch, or campfire. Using the device requires your action.</li>
          <li><em><strong>Music Box.</strong></em> When opened, this music box plays a single song at a moderate volume. The box stops playing when it reaches the song's end or when it is closed.</li>
          <li>At your DM's discretion, you may make other objects with effects similar in power to these. The Prestidigitation cantrip is a good baseline for such effects.</li>
          </ul>
          </li>
          </ul>
      `,
        features: [
          {
            name: 'Tinker',
            level: 0,
            isAbility: true,
            description: `
              <li>You have proficiency with artisan tools (tinker's tools). Using those tools, you can spend 1 hour and 10 gp worth of materials to construct a Tiny clockwork device (AC 5, 1 hp). The device ceases to function after 24 hours (unless you spend 1 hour repairing it to keep the device functioning), or when you use your action to dismantle it; at that time, you can reclaim the materials used to create it. You can have up to three such devices active at a time. When you create a device, choose one of the following options:
              <ul>
              <li><em><strong>Clockwork Toy.</strong></em> This toy is a clockwork animal, monster, or person, such as a frog, mouse, bird, dragon, or soldier. When placed on the ground, the toy moves 5 feet across the ground on each of your turns in a random direction. It makes noises as appropriate to the creature it represents.</li>
              <li><em><strong>Fire Starter.</strong></em> The device produces a miniature flame, which you can use to light a candle, torch, or campfire. Using the device requires your action.</li>
              <li><em><strong>Music Box.</strong></em> When opened, this music box plays a single song at a moderate volume. The box stops playing when it reaches the song's end or when it is closed.</li>
              <li>At your DM's discretion, you may make other objects with effects similar in power to these. The Prestidigitation cantrip is a good baseline for such effects.</li>
              </ul>
              </li>
            `,
          },
        ],
      },
      {
        title: 'Mark of Scribing',
        description: `
          <p><strong><em>If you're a gnome with the Mark of Scribing, you have this subrace, with the following traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 1</li>
          </ul>
          <ul>
          <li><strong>Gifted Scribe.</strong> Whenever you make an Intelligence (History) or an Ability Check involving Calligrapher's Supplies, you can roll a d4 and add the number rolled to the total ability check.</li>
          </ul>
          <ul>
          <li><strong>Scribe's Insight.</strong> You know the Message cantrip. You can also cast the Comprehend Languages spell with this trait. Starting at 3rd level, you can also cast the Magic Mouth spell with it. Once you cast either spell with this trait, you can't cast that spell again until you finish a Long Rest. Intelligence is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Scribing Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Scribing Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td>Comprehend Languages, Illusory Script</td>
          </tr>
          <tr>
          <td>2nd</td>
          <td>Animal Messenger, Silence</td>
          </tr>
          <tr>
          <td>3rd</td>
          <td>Sending, Tongues</td>
          </tr>
          <tr>
          <td>4th</td>
          <td>Arcane Eye, Divination</td>
          </tr>
          <tr>
          <td>5th</td>
          <td>Dream</td>
          </tr>
          </table>
        `,
        features: [
          {
            name: 'Gifted Scribing',
            level: 0,
            isAbility: false,
            description: `
              <p> Whenever you make an Intelligence (History) or an Ability Check involving Calligrapher's Supplies, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
    ],
  };

  private halfElf: any = {
    title: 'halfElf',
    content: [
      {
        title: "Player's Handbook",
        description: `
          <em><strong>Walking in two worlds but truly belonging to neither, half-elves combine what some say are the best qualities of their elf and human parents: human curiosity, inventiveness, and ambition tempered by the refined senses, love of nature, and artistic tastes of the elves.</strong></em></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 2, and two other ability scores of your choice each increase by 1.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Half-elves age at much the same rate as humans, reaching adulthood at the age of 20. They live much longer than humans, however, often exceeding 180 years.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Half-elves share the chaotic bent of their elven heritage. They both value personal freedom and creative expression, demonstrating neither love of leaders nor desire for followers. They chafe at rules, resent others' demands, and sometimes prove unreliable, or at least unpredictable. They are good and evil in equal numbers, a trait they share with their human parents.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Half-elves are more or less the same size as humans, ranging from 5 to 6 feet tall. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can read, speak, and write Common, Elven, and one language of your choice.</li>
          </ul>
          <ul>
          <li><strong>Half-Elf Versatility.</strong> Choose one of the following traits:
          <ul>
          <li><em><strong>Skill Versatility (General).</strong></em> You gain proficiency in two skills of your choice.</li>
          <li><em><strong>Elf Weapon Training (High or Wood Elf Heritage).</strong></em> You have proficiency with the longsword, shortsword, shortbow, and longbow.</li>
          <li><em><strong>Cantrip (High Elf Heritage).</strong></em> You know one cantrip of your choice from the wizard spell list. Intelligence is your spellcasting ability for it.</li>
          <li><em><strong>Fleet of Foot (Wood Elf Heritage).</strong></em> Your base walking speed increases to 35 feet.</li>
          <li><em><strong>Mask of the Wild (Wood Elf Heritage).</strong></em> You can attempt to hide even when you are only lightly obscured by foliage, heavy rain, falling snow, mist, and other natural phenomena.</li>
          <li><em><strong>Drow Magic (Dark Elf Heritage).</strong></em> You know the Dancing Lights cantrip. When you reach 3rd level, you can cast Faerie Fire once, and it recharges after a long rest. When you reach 5th level, you can cast Darkness once, and it recharges after a long rest. Charisma is your spellcasting ability for these spells.</li>
          <li><em><strong>Swim Speed (Aquatic Elf Heritage).</strong></em> You have a swimming speed of 30 feet.</li>
          </ul>
          </li>
          </ul>
        `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Thanks to your elven heritage, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
          {
            name: 'Fey Ancestry',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws against being charmed, and magic can't put you to sleep.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Detection',
        description: `
          <p><strong><em>If your Half-Elf has the Mark of Detection, these features replace the Ability Score Increase and the Half-Elf Versatility traits in the</em> Player's Handbook.</strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 2, and one other Ability Score of your choice increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Magical Detection.</strong> You can cast the Detect Magic and the Detect Poison and Disease spells with this trait. Starting at 3rd level, you can also cast the See Invisibility spell with it. Once you cast either spell with this trait, you can't cast that spell again until you finish a Long Rest. Intelligence is your Spellcasting Ability for these spells, and you don't require material components for them.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Detection Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Detection Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td>Detect Magic, Detect Poison and Disease</td>
          </tr>
          <tr>
          <td>2nd</td>
          <td>Detect Thoughts, Find Traps</td>
          </tr>
          <tr>
          <td>3rd</td>
          <td>Clairvoyance, Nondetection</td>
          </tr>
          <tr>
          <td>4th</td>
          <td>Arcane Eye,Divination</td>
          </tr>
          <tr>
          <td>5th</td>
          <td>Legend Lore</td>
          </tr>
          </table>
        `,
        features: [
          {
            name: 'Deductive Intuition',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make a Intelligence (Investigation) or a Wisdom (Insight) check, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Storm',
        description: `
          <p><strong><em>If your Half-Elf has the Mark of Storm, these features replace the Ability Score Increase and the Half-Elf Versatility traits in the</em> Player's Handbook.</strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 2, and your Dexterity score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Headwinds.</strong> You know the Gust cantrip. Starting at 3rd level, you can also cast the Gust of Wind spell with it. Once you cast this spell with this trait, you can't cast that spell again until you finish a Long Rest. Charisma is your Spellcasting Ability for this spell.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Storm Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Storm Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td>Feather Fall, Fog Cloud</td>
          </tr>
          <tr>
          <td>2nd</td>
          <td>Gust of Wind, Levitate</td>
          </tr>
          <tr>
          <td>3rd</td>
          <td>Sleet Storm, Wind Wall</td>
          </tr>
          <tr>
          <td>4th</td>
          <td>Conjure Minor Elementals, Control Water</td>
          </tr>
          <tr>
          <td>5th</td>
          <td>Conjure Elemental</td>
          </tr>
          </table>
          </div>
        `,
        features: [
          {
            name: "Windwright's Intuition",
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make a Dexterity (Acrobatics) check or any Ability Check involving Navigator's Tools, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
          {
            name: "Storm's Boon",
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to Lightning damage.</p>
            `,
          },
        ],
      },
    ],
  };

  private halfOrc: any = {
    title: 'halfOrc',
    content: [
      {
        title: "Player's Handbook",
        description: `
          <p><em><strong>When alliances between humans and orcs are sealed by marriages, half-orcs are born. Some half-orcs rise to become proud chiefs of orc tribes, their human blood giving them an edge over their full-blooded orc rivals. Some venture into the world to prove their worth among humans and other more civilized races. Many of these become adventurers, achieving greatness for their mighty deeds and notoriety for their barbaric customs and savage fury.</strong></em></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Strength score increases by 2, and your Constitution score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Half-orcs mature a little faster than humans, reaching adulthood around age 14. They age noticeably faster and rarely live longer than 75 years.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Half-orcs inherit a tendency toward chaos from their orc parents and are not strongly inclined toward good. Half-orcs raised among orcs and willing to live out their lives among them are usually evil.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Half-orcs are somewhat larger and bulkier than humans, and they range from 5 to well over 6 feet tall. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Menacing.</strong> You gain proficiency in the Intimidation skill.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Orc. Orc is a harsh, grating language with hard consonants. It has no script of its own but is written in the Dwarvish script.</li>
          </ul>
        `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>Thanks to your orc blood, you have superior vision in dark and dim conditions. You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
          {
            name: 'Relentless Endurance',
            level: 0,
            isAbility: false,
            description: `
            <p>When you are reduced to 0 hit points but not killed outright, you can drop to 1 hit point instead. You can't use this feature again until you finish a long rest.</p>
            `,
          },
          {
            name: 'Savage Attacks',
            level: 0,
            isAbility: false,
            description: `
            <p>When you score a critical hit with a melee weapon attack, you can roll one of the weapon's damage dice one additional time and add it to the extra damage of the critical hit.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Finding',
        description: `
          <p><strong><em>If your Half-Orc has the Mark of Finding, replace all Racial Traits found in the</em> Player's Handbook <em>with these, except for Age, Alignment, Size, and Speed.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 2, and your Constitution score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Finder's Magic.</strong> You can cast the <a href="http://dnd5e.wikidot.com/spell:hunters-mark" target="_blank">Hunter's Mark</a> spell with this trait. Starting at 3rd level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:locate-object" target="_blank">Locate Object</a> spell with it. Once you cast either spell with this trait, you can't cast that spell again until you finish a Long Rest. Wisdom is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Goblin.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Finding Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Finding Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td><a href="http://dnd5e.wikidot.com/spell:Faerie-Fire" target="_blank">Faerie Fire</a>, <a href="http://dnd5e.wikidot.com/spell:longstrider" target="_blank">Longstrider</a></td>
          </tr>
          <tr>
          <td>2nd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:locate-animals-or-plants" target="_blank">Locate Animals or Plants</a>, <a href="http://dnd5e.wikidot.com/spell:locate-object" target="_blank">Locate Object</a></td>
          </tr>
          <tr>
          <td>3rd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:clairvoyance" target="_blank">Clairvoyance</a>, <a href="http://dnd5e.wikidot.com/spell:speak-with-plants" target="_blank">Speak With Plants</a></td>
          </tr>
          <tr>
          <td>4th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:divination" target="_blank">Divination</a>, <a href="http://dnd5e.wikidot.com/spell:locate-creature" target="_blank">Locate Creature</a></td>
          </tr>
          <tr>
          <td>5th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:commune-with-nature" target="_blank">Commune With Nature</a></td>
          </tr>
          </table>
          </div>
        `,
        features: [
          {
            name: "Hunter's Intuition",
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make a Wisdom (Perception) or a Wisdom (Survival) check, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see in dim light within 60ft. of you as if it were bright light, and in darkness as if it were dim light. You can't discern colors in darkness, only shades of grey.</p>
            `,
          },
        ],
      },
    ],
  };

  private halfling: any = {
    title: 'halfling',
    content: [
      {
        title: "Player's Handbook",
        description: `
          <p><em><strong>The comforts of home are the goals of most halflings' lives: a place to settle in peace and quiet, far from marauding monsters and clashing armies. Others form nomadic bands that travel constantly, lured by the open road and the wide horizon to discover the wonders of new lands and peoples. Halflings work readily with others, and they are loyal to their friends, whether halfling or otherwise. They can display remarkable ferocity when their friends, families, or communities are threatened.</strong></em></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity score increases by 2.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> A halfling reaches adulthood at the age of 20 and generally lives into the middle of his or her second century.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Most halflings are lawful good. As a rule, they are good-hearted and kind, hate to see others in pain, and have no tolerance for oppression. They are also very orderly and traditional, leaning heavily on the support of their community and the comfort of the old ways.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Halflings average about 3 feet tall and weigh about 40 pounds. Your size is small.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 25 feet.</li>
          </ul>

          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Halfling.</li>
          </ul>
        `,
        features: [
          {
            name: 'Lucky',
            level: 0,
            isAbility: false,
            description: `
            <p>When you roll a 1 on an attack roll, ability check, or saving throw, you can reroll the die. You must use the new result, even if it is a 1.</p>
            `,
          },
          {
            name: 'Brave',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws against being frightened.</p>
            `,
          },
          {
            name: 'Nimble',
            level: 0,
            isAbility: false,
            description: `
            <p>You can move through the space of any creature that is of a size larger than yours.</p>
            `,
          },
        ],
      },
      {
        title: 'Lightfoot',
        description: `
          <p><strong><em>As a lightfoot halfling, you can easily hide from notice, even using other people as cover. You're inclined to be affable and get along well with others. In the Forgotten Realms, lightfoot halflings have spread the farthest and thus are the most common variety.</em></strong></p>
          <p><strong><em>Lightfoots are more prone to wanderlust than other halflings, and often dwell alongside other races or take up a nomadic life. In the world of Grayhawk, these halflings are called hairfeet or tallfellows.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 1.</li>
          </ul>
        `,
        features: [
          {
            name: 'Naturally Stealthy',
            level: 0,
            isAbility: false,
            description: `
            <p>You can attempt to hide even when you are obscured only by a creature that is at least one size larger than you.</p>
            `,
          },
        ],
      },
      {
        title: 'Stout',
        description: `
          <p><strong><em>As a stout halfling, you're hardier than average and have some resistance to poison. Some say that stouts have dwarven blood. In the Forgotten Realms, these halflings are called stronghearts, and they're most common in the south.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Constitution score increases by 1.</li>
          </ul>
        `,
        features: [
          {
            name: 'Stout Resilience',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws against poison, and you have resistance to poison damage.</p>
            `,
          },
        ],
      },
      {
        title: 'Ghostwise',
        description: `
          <p><strong><em>Ghostwise halflings trace their ancestry back to a war among halfling tribes that sent their ancestors into flight from Luiren. Ghostwise halflings are the rarest of the</em> hin, <em>found only in the Chondalwood and a few other isolated forests, clustered in tight-knit clans.</em></strong></p>
          <p><strong><em>Many ghostwise clans select a natural landmark as the center of their territory, and members carry a piece of that landmark with them at all times. Clan warriors known as nightgliders bond with and ride giant owls as mounts.</em></strong></p>
          <p><strong><em>Because these folk are clannish and mistrustful of outsiders, ghostwise halfling adventurers are rare. Ask your DM if you can play a member of this subrace, which has the halfling traits in the</em> Player's Handbook, <em>plus the subrace traits below.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
        `,
        features: [
          {
            name: 'Silent Speech',
            level: 0,
            isAbility: false,
            description: `
            <p>You can speak telepathically to any creature within 30 feet of you. The creature understands you only if the two of you share a language. You can speak telepathically in this way to one creature at a time.</p>
            `,
          },
        ],
      },
      {
        title: 'Lotusden',
        description: `
          <p><strong><em>Long tied to the natural heart of the Lotusden Greenwood, these halflings have adapted to live synergistically with the chaotic laws of the wilds.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Children of the Woods.</strong> You know the <a href="/spell:druidcraft">Druidcraft</a> Cantrip. At 3rd level, you can cast the <a href="/spell:entangle">Entangle</a> spell once per long rest. At 5th level, you can cast <a href="/spell:spike-growth">Spike Growth</a> spell once per long rest. These spells don't require the material components normally required. Wisdom is your spellcasting ability for these spells.</li>
          </ul>
        `,
        features: [
          {
            name: 'Timberwalk',
            level: 0,
            isAbility: false,
            description: `
            <p>Ability checks made to track you are at disadvantage and you can move through difficult terrain made of non-magical plants and overgrowth without expending extra movement.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Hospitality',
        description: `
          <p><strong><em>If you're a halfling with the Mark of Hospitality, you have this subrace, with the following traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Innkeeper's Magic.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:prestidigitation" target="_blank">Prestidigitation</a> cantrip. You can also cast <a href="http://dnd5e.wikidot.com/spell:purify-food-and-drink" target="_blank">Purify Food and Drink</a> and <a href="http://dnd5e.wikidot.com/spell:unseen-servant" target="_blank">Unseen Servant</a> with this trait. Once you cast either spell with this trait, you can't cast that spell again until you finish a long rest. Charisma is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class features, the spells on the Mark of Hospitality Spells table are added to the spell list of your spellcasting class.</li>
          </ul>
          <p><strong>Mark of Hospitality Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td><a href="http://dnd5e.wikidot.com/spell:goodberry" target="_blank">Goodberry</a>, <a href="http://dnd5e.wikidot.com/spell:sleep" target="_blank">Sleep</a></td>
          </tr>
          <tr>
          <td>2nd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:aid" target="_blank">Aid</a>, <a href="http://dnd5e.wikidot.com/spell:calm-emotions" target="_blank">Calm Emotions</a></td>
          </tr>
          <tr>
          <td>3rd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:create-food-and-water" target="_blank">Create Food and Water</a>, <a href="http://dnd5e.wikidot.com/spell:leomunds-tiny-hut" target="_blank">Leomund's Tiny Hut</a></td>
          </tr>
          <tr>
          <td>4th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:aura-of-purity" target="_blank">Aura of Purity</a>, <a href="http://dnd5e.wikidot.com/spell:mordenkainens-private-sanctum" target="_blank">Mordenkainen's Private Sanctum</a></td>
          </tr>
          <tr>
          <td>5th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:hallow" target="_blank">Hallow</a></td>
          </tr>
          </table>
        `,
        features: [
          {
            name: 'Ever Hospitable',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you roll a Charisma (Persuasion) check or an ability check involving Brewer's Tools or Cook's Utensils, roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Healing',
        description: `
          <p><strong><em>If you're a halfling with the Mark of Healing, you have this subrace, with the following traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Healing Touch.</strong> You can cast the <a href="http://dnd5e.wikidot.com/spell:cure-wounds" target="_blank">Cure Wounds</a> spell with this trait. Beginning at 3rd level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:lesser-restoration" target="_blank">Lesser Restoration</a> spell with this trait. Once you cast either spell with this trait, you can't cast that spell again until you finish a long rest. Wisdom is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class features, the spells on the Mark of Healing Spells table are added to the spell list of your spellcasting class.</li>
          </ul>
          <p><strong>Mark of Healing Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td><a href="http://dnd5e.wikidot.com/spell:cure-wounds" target="_blank">Cure Wounds</a>, <a href="http://dnd5e.wikidot.com/spell:healing-word" target="_blank">Healing Word</a></td>
          </tr>
          <tr>
          <td>2nd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:lesser-restoration" target="_blank">Lesser Restoration</a>, <a href="http://dnd5e.wikidot.com/spell:prayer-of-healing" target="_blank">Prayer of Healing</a></td>
          </tr>
          <tr>
          <td>3rd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:aura-of-vitality" target="_blank">Aura of Vitality</a>, <a href="http://dnd5e.wikidot.com/spell:mass-healing-word" target="_blank">Mass Healing Word</a></td>
          </tr>
          <tr>
          <td>4th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:aura-of-purity" target="_blank">Aura of Purity</a>, <a href="http://dnd5e.wikidot.com/spell:aura-of-life" target="_blank">Aura of Life</a></td>
          </tr>
          <tr>
          <td>5th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:greater-restoration" target="_blank">Greater Restoration</a></td>
          </tr>
          </table>
          </div>
          `,
        features: [
          {
            name: 'Medical Intuition',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you roll a Wisdom (Medicine) check or an ability check involving an Herbalism Kit, roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
    ],
  };

  private human: any = {
    title: 'human',
    content: [
      {
        title: "Player's Handbook",
        description: `
          <p><em><strong>In the reckonings of most worlds, humans are the youngest of the common races, late to arrive on the world scene and short-lived in comparison to dwarves, elves, and dragons. Perhaps it is because of their shorter lives that they strive to achieve as much as they can in the years they are given. Or maybe they feel they have something to prove to the elder races, and that's why they build their mighty empires on the foundation of conquest and trade. Whatever drives them, humans are the innovators, the achievers, and the pioneers of the worlds.</strong></em></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your ability scores each increase by 1.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Humans reach adulthood in their late teens and live less than a century.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Humans tend toward no particular alignment. The best and the worst are found among them.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Humans vary widely in height and build, from barely 5 feet to well over 6 feet tall. Regardless of your position in that range, your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one extra language of your choice. Humans typically learn the languages of other peoples they deal with, including obscure dialects. They are fond of sprinkling their speech with words borrowed from other tongues: Orc curses, Elvish musical expressions, Dwarvish military phrases, and so on.</li>
          </ul>
          `,
      },
      {
        title: 'Variant',
        description: `
          <p><strong><em>If your campaign uses the optional feat rules from chapter 5 of the</em> Player's Handbook, <em>your Dungeon Master might allow these variant traits, all of which replace the human's</em> Ability Score Increase <em>trait.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Two different ability scores of your choice increase by 1.</li>
          </ul>
          <ul>
          <li><strong>Skills.</strong> You gain proficiency in one skill of your choice.</li>
          </ul>
          <ul>
          <li><strong>Feat.</strong> You gain one <a href="http://dnd5e.wikidot.com/#toc6">Feat</a> of your choice.</li>
          </ul>
        `,
      },
      {
        title: 'Mark of Finding',
        description: `
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 2, and your Constitution score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Finder's Magic.</strong> You can cast the <a href="http://dnd5e.wikidot.com/spell:hunters-mark" target="_blank">Hunter's Mark</a> spell with this trait. Starting at 3rd level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:locate-object" target="_blank">Locate Object</a> spell with it. Once you cast either spell with this trait, you can't cast that spell again until you finish a Long Rest. Wisdom is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Goblin.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Finding Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Finding Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td><a href="http://dnd5e.wikidot.com/spell:Faerie-Fire" target="_blank">Faerie Fire</a>, <a href="http://dnd5e.wikidot.com/spell:longstrider" target="_blank">Longstrider</a></td>
          </tr>
          <tr>
          <td>2nd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:locate-animals-or-plants" target="_blank">Locate Animals or Plants</a>, <a href="http://dnd5e.wikidot.com/spell:locate-object" target="_blank">Locate Object</a></td>
          </tr>
          <tr>
          <td>3rd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:clairvoyance" target="_blank">Clairvoyance</a>, <a href="http://dnd5e.wikidot.com/spell:speak-with-plants" target="_blank">Speak With Plants</a></td>
          </tr>
          <tr>
          <td>4th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:divination" target="_blank">Divination</a>, <a href="http://dnd5e.wikidot.com/spell:locate-creature" target="_blank">Locate Creature</a></td>
          </tr>
          <tr>
          <td>5th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:commune-with-nature" target="_blank">Commune With Nature</a></td>
          </tr>
          </table>
          `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see in dim light within 60ft. of you as if it were bright light, and in darkness as if it were dim light. You can't discern colors in darkness, only shades of grey.</p>
            `,
          },
          {
            name: "Hunter's Intuition",
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make a Wisdom (Perception) or a Wisdom (Survival) check, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Handling',
        description: `
          <p><strong><em>If your Human has the Mark of Handling, replace all Racial Traits found in the</em> Player's Handbook <em>with these, except for Age, Alignment, Size, and Speed.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 2, and one other Ability Score of your choice increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Primal Connection.</strong> You can cast the <a href="http://dnd5e.wikidot.com/spell:animal-friendship" target="_blank">Animal Friendship</a> spell and the <a href="http://dnd5e.wikidot.com/spell:speak-with-animals" target="_blank">Speak With Animals</a> with this trait, requiring no material components. Once you cast either spell with this trait, you can't cast that spell again until you finish a Long Rest. Wisdom is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>The Bigger They Are.</strong> Starting at 3rd level, you can target a Beast or a Monstrosity when you cast <a href="http://dnd5e.wikidot.com/spell:animal-friendship" target="_blank">Animal Friendship</a> or <a href="http://dnd5e.wikidot.com/spell:speak-with-animals" target="_blank">Speak With Animals</a>, provided that the creature's intelligence is 3 or lower.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Handling Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Handling Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td><a href="http://dnd5e.wikidot.com/spell:animal-friendship" target="_blank">Animal Friendship</a>, <a href="http://dnd5e.wikidot.com/spell:speak-with-animals" target="_blank">Speak With Animals</a></td>
          </tr>
          <tr>
          <td>2nd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:beast-sense" target="_blank">Beast Sense</a>, <a href="http://dnd5e.wikidot.com/spell:calm-emotions" target="_blank">Calm Emotions</a></td>
          </tr>
          <tr>
          <td>3rd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:beacon-of-hope" target="_blank">Beacon of Hope</a>, <a href="http://dnd5e.wikidot.com/spell:conjure-animals" target="_blank">Conjure Animals</a></td>
          </tr>
          <tr>
          <td>4th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:aura-of-life" target="_blank">Aura of Life</a>, <a href="http://dnd5e.wikidot.com/spell:dominate-beast" target="_blank">Dominate Beast</a></td>
          </tr>
          <tr>
          <td>5th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:awaken" target="_blank">Awaken</a></td>
          </tr>
          </table>
          `,
        features: [
          {
            name: 'Wild Intuition',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make a Wisdom (Animal Handling) or a Intelligence (Nature) check, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Making',
        description: `
          <p><strong><em>If your Human has the Mark of Making, replace all Racial Traits found in the</em> Player's Handbook <em>with these, except for Age, Alignment, Size, and Speed.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 2, and one other Ability Score of your choice increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Artisan's Gift</strong> You gain proficiency in one type of Artisan's Tools of your choice.</li>
          </ul>
          <ul>
          <li><strong>Spellsmith.</strong> You learn the <a href="http://dnd5e.wikidot.com/spell:mending" target="_blank">Mending</a> cantrip. You can also cast the <a href="http://dnd5e.wikidot.com/spell:magic-weapon" target="_blank">Magic Weapon</a> spell with this trait. When you do so, the spell lasts for 1 hour and doesn't require concentration. Once you cast this spell with this trait, you can't cast that spell again until you finish a Long Rest. Intelligence is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Making Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
        `,
        features: [
          {
            name: "Artisan's Gift",
            level: 0,
            isAbility: false,
            description: `
            <p>You gain proficiency in one type of Artisan's Tools of your choice.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Passage',
        description: `
          <p><strong><em>If your Human has the Mark of Passage, replace all Racial Traits found in the</em> Player's Handbook <em>with these, except for Age, Alignment, and Size.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity score increases by 2, and one other Ability Score of your choice increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Courier's Speed</strong> You gain a base walking speed of 35ft.</li>
          </ul>
          <ul>
          <li><strong>Magical Passage.</strong> You can cast the <a href="http://dnd5e.wikidot.com/spell:misty-step" target="_blank">Misty Step</a> spell with this trait. Once you cast this spell with this trait, you can't cast that spell again until you finish a Long Rest. Dexterity is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Passage Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Passage Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td><a href="http://dnd5e.wikidot.com/spell:expeditious-retreat" target="_blank">Expeditious Retreat</a>, <a href="http://dnd5e.wikidot.com/spell:jump" target="_blank">Jump</a></td>
          </tr>
          <tr>
          <td>2nd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:misty-step" target="_blank">Misty Step</a>, <a href="http://dnd5e.wikidot.com/spell:pass-without-trace" target="_blank">Pass Without Trace</a></td>
          </tr>
          <tr>
          <td>3rd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:blink" target="_blank">Blink</a>, <a href="http://dnd5e.wikidot.com/spell:phantom-steed" target="_blank">Phantom Steed</a></td>
          </tr>
          <tr>
          <td>4th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:dimension-door" target="_blank">Dimension Door</a>, <a href="http://dnd5e.wikidot.com/spell:freedom-of-movement" target="_blank">Freedom of Movement</a></td>
          </tr>
          <tr>
          <td>5th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:teleportation-circle" target="_blank">Teleportation Circle</a></td>
          </tr>
          </table>
          `,
        features: [
          {
            name: 'Intuitive Motion',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make an Dexterity (Acrobatics) or an Ability Check involving operating or maintaining a Land Vehicle, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
      {
        title: 'Mark of Sentinel',
        description: `
          <p><strong><em>If your Human has the Mark of Sentinel, replace all Racial Traits found in the</em> Player's Handbook <em>with these, except for Age, Alignment, Size, and Speed.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Constitution score increases by 2, and your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Guardian's Shield.</strong> You can cast the <a href="http://dnd5e.wikidot.com/spell:shield" target="_blank">Shield</a> spell with this trait. Once you cast this spell with this trait, you can't cast that spell again until you finish a Long Rest. Wisdom is your Spellcasting Ability for these spells.</li>
          </ul>
          <ul>
          <li><strong>Spells of the Mark.</strong> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Sentinel Spells table are added to the spell list of your Spellcasting class.</li>
          </ul>
          <p><strong>Mark of Sentinel Spells</strong></p>
          <table class='table'>
          <tr>
          <th>Spell Level</th>
          <th>Spell</th>
          </tr>
          <tr>
          <td>1st</td>
          <td><a href="http://dnd5e.wikidot.com/spell:compelled-duel" target="_blank">Compelled Duel</a>, <a href="http://dnd5e.wikidot.com/spell:shield-of-faith" target="_blank">Shield of Faith</a></td>
          </tr>
          <tr>
          <td>2nd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:warding-bond" target="_blank">Warding Bond</a>, <a href="http://dnd5e.wikidot.com/spell:zone-of-truth" target="_blank">Zone of Truth</a></td>
          </tr>
          <tr>
          <td>3rd</td>
          <td><a href="http://dnd5e.wikidot.com/spell:counterspell" target="_blank">Counterspell</a>, <a href="http://dnd5e.wikidot.com/spell:protection-from-energy" target="_blank">Protection From Energy</a></td>
          </tr>
          <tr>
          <td>4th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:death-ward" target="_blank">Death Ward</a>, <a href="http://dnd5e.wikidot.com/spell:guardian-of-faith" target="_blank">Guardian of Faith</a></td>
          </tr>
          <tr>
          <td>5th</td>
          <td><a href="http://dnd5e.wikidot.com/spell:bigbys-hand" target="_blank">Bigby's Hand</a></td>
          </tr>
          </table>
        `,
        features: [
          {
            name: "Sentinel's Intuition",
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make an Wisdom (Insight) or a Wisdom (Perception) check, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
          {
            name: 'Vigilant Guardian',
            level: 0,
            isAbility: true,
            description: `
            <p>Once a creature that you can see within 5ft of you is hit with an attack roll, you can use your reaction to swap places with the creature, and you are hit by the attack instead. Once you use this trait, you can't do so again until you finish a long rest.</p>
            `,
          },
        ],
      },
      {
        title: 'Keldron',
        description: `
          <p><strong><em>The people of Keld are human, but they are like no other humans anywhere. Nearly all adults stand over six feet tall, and heights above seven feet are not uncommon. They are massively muscled and have gray skin, ranging from an ashy gray-white to a deeper bluegray. The typical Keldon’s hairline points sharply down in the middle of the forehead and at either temple, but recedes elsewhere — sometimes dramatically. Keldons are remarkably resistant to the cold of their homeland, baring skin even in near-freezing temperatures without discomfort.</em></strong></p>
          <p><strong><em>Keldons value self-reliance, strength, and courage above all else. Anything that is the product of their own labor is a fine thing. Anything else is treated with a healthy dose of skepticism. At best, they are a proud, pragmatic, passionate people, and their loyalty is fierce once earned. At worst, they can be reckless, hot-tempered, and violent — and no small number of Keldons still consider these qualities virtues rather than vices.</em></strong></p>
          <p><strong><em>The humans of Keld have the following traits, which replace the standard human traits presented in the</em> Player’s Handbook.</strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Strength score increases by 2, and your Constitution score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Keldons reach adulthood in their late teens and live less than a century.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Keldons tend toward chaotic alignments, and many walk a fine line between good and evil.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Keldons are taller and heavier than the human norms of other cultures, standing almost universally above 6 feet tall and reaching heights above 7 feet. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Keldon.</li>
          </ul>
          <ul>
          <li><strong>Natural Athlete.</strong> You have proficiency in the Athletics skill.</li>
          </ul>
          <ul>
          <li><strong>Keldon Resilience.</strong> You have proficiency in Strength saving throws.</li>
          </ul>
        `,
        features: [
          {
            name: 'Icehaven Born',
            level: 0,
            isAbility: false,
            description: `
            <p>You are naturally adapted to cold climates, as described in chapter 5 of the <em>Dungeon Master’s Guide</em>.</p>
            `,
          },
        ],
      },
      {
        title: 'Innistrad',
        description: `
          <p><strong><em>Innistrad’s population is mostly human, and player characters in an Innistrad campaign should be human in most circumstances. However, the humans of Kessig are different in many respects from those of Gavony, and Nephalia’s urban culture is very distinct from the shadow-draped land of Stensia. Diversity among player characters comes not from race, but from each character’s home province.</em></strong></p>
          <p><strong><em>Human characters on Innistrad have the following traits. If you use these human traits, do not use the variant human traits presented in the Player’s Handbook. As well, in campaigns that use feats, characters should not be allowed to choose feats that duplicate any provincial traits.</em></strong></p>
          <ul>
          <li><strong>Age.</strong> Humans reach adulthood in their late teens and live less than a century.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Humans tend toward no particular alignment.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Humans vary widely in height and build, from barely 5 feet to well over 6 feet tall. Regardless of your position in that range, your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one extra language of your choice.</li>
          </ul>
          <ul>
          <li><strong>Provincial Origin.</strong> Choose one of the four provinces of Innistrad as the place of origin for your character: <a href="/lineage:human-gavony">Gavony</a>, <a href="/lineage:human-kessig">Kessig</a>, <a href="/lineage:human-nephalia">Nephalia</a>, or <a href="/lineage:human-stensia">Stensia</a>.</li>
          </ul>
    `,
      },
      {
        title: 'Gavony',
        description: `
          <p><strong><em>Whether safe behind the walls of the High City of Thraben or out in the moors with little more than shuttered windows, barred doors, and grim determination to stand against the horrors of the night, the humans of Gavony are the most well-rounded people of Innistrad.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your ability scores each increase by 1.</li>
          </ul>
        `,
      },
      {
        title: 'Kessig',
        description: `
          <p><strong><em>For the Kessiger, life is work. Kessigers are farmers, millers, weavers, and stonemasons, living close to the land and working hard for every meal. This makes them self-reliant, pragmatic, and plainspoken.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity and Wisdom scores each increase by 1.</li>
          </ul>
          <ul>
          <li><strong>Forest Folk.</strong> You have proficiency in the Survival skill.</li>
          </ul>
          <ul>
          <li><strong>Fleet of Foot.</strong> Your base walking speed is 40 feet.</li>
          </ul>
          <ul>
          <li><strong>Sure-Footed.</strong> When you use the Dash action, difficult terrain doesn’t cost you extra movement on that turn.</li>
          </ul>
          <ul>
          <li><strong>Spring Attack.</strong> When you make a melee attack against a creature, you don’t provoke opportunity attacks from that creature for the rest of your turn, whether you hit or not.</li>
          </ul>
        `,
        features: [
          {
            name: 'Sure-Footed',
            level: 0,
            isAbility: false,
            description: `
            <p>When you use the Dash action, difficult terrain doesn’t cost you extra movement on that turn.</p>
            `,
          },
          {
            name: 'Spring Attack',
            level: 0,
            isAbility: false,
            description: `
            <p>When you make a melee attack against a creature, you don’t provoke opportunity attacks from that creature for the rest of your turn, whether you hit or not.</p>
            `,
          },
        ],
      },
      {
        title: 'Nephalia',
        description: `
          <p><strong><em>Beneath an ever-present shroud of fog billowing in from the sea, the people of Nephalia maintain a semblance of normalcy, buying and selling goods from across Innistrad in their bustling markets, setting out to sea in tiny fishing boats, or tilling the soggy earth in waterlogged fields.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Intelligence and Charisma scores each increase by 1.</li>
          </ul>
          <ul>
          <li><strong>Breadth of Knowledge.</strong> You gain proficiency in any combination of four skills or with four tools of your choice.</li>
          </ul>
        `,
      },
      {
        title: 'Stensia',
        description: `
          <p><strong><em>Countless generations of hardship and proximity to the vampire strongholds—leading to lost children and neighbors—have taught Stensians to guard their hearts. They are proud and fervent in their beliefs but seem brusque or even cold to the people of other provinces.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Strength and Constitution scores each increase by 1.</li>
          </ul>
          <ul>
          <li><strong>Daunting.</strong> You have proficiency in the Intimidation skill.</li>
          </ul>
          <ul>
          <li><strong>Tough.</strong> Your hit point maximum increases by 2, and it increases by 2 every time you gain a level.</li>
          </ul>
          </div>
        `,
      },
    ],
  };

  private dragonborn: any = {
    title: 'dragonborn',
    content: [
      {
        title: "Player's Handbook",
        description: `
        <p><strong><em>Born of dragons, as their name proclaims, the dragonborn walk proudly through a world that greets them with fearful incomprehension. Shaped by draconic gods or the dragons themselves, dragonborn originally hatched from dragon eggs as a unique race, combining the best attributes of dragons and humanoids. Some dragonborn are faithful servants to true dragons, others form the ranks of soldiers in great wars, and still others find themselves adrift, with no clear calling in life.</em></strong></p>
        <ul>
        <li><strong>Ability Score Increase.</strong> Your Strength score increases by 2, and your Charisma score increases by 1.</li>
        </ul>
        <ul>
        <li><strong>Age.</strong> Young dragonborn grow quickly. They walk hours after hatching, attain the size and development of a 10-year-old human child by the age of 3, and reach adulthood by 15. They live to be around 80.</li>
        </ul>
        <ul>
        <li><strong>Alignment.</strong> Dragonborn tend towards extremes, making a conscious choice for one side or the other between Good and Evil (represented by Bahamut and Tiamat, respectively). More side with Bahamut than Tiamat (whose non-dragon followers are mostly kobolds), but villainous dragonborn can be quite terrible indeed. Some rare few choose to devote themselves to lesser dragon deities, such as Chronepsis (Neutral), and fewer still choose to worship Io, the Ninefold Dragon, who is all alignments at once.</li>
        </ul>
        <ul>
        <li><strong>Size.</strong> Dragonborn are taller and heavier than humans, standing well over 6 feet tall and averaging almost 250 pounds. Your size is Medium.</li>
        </ul>
        <ul>
        <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
        </ul>
        <ul>
        <li><strong>Draconic Ancestry.</strong> You are distantly related to a particular kind of dragon. Choose a type of dragon from the below list; this determines the damage and area of your breath weapon, and the type of resistance you gain.</li>
        </ul>
        <table class='table'>
        <tr>
        <th>Dragon Color</th>
        <th>Damage Type</th>
        <th>Breath Weapon</th>
        </tr>
        <tr>
        <td>Black</td>
        <td>Acid</td>
        <td>5' by 30' line (DEX save)</td>
        </tr>
        <tr>
        <td>Blue</td>
        <td>Lightning</td>
        <td>5' by 30' line (DEX save)</td>
        </tr>
        <tr>
        <td>Brass</td>
        <td>Fire</td>
        <td>5' by 30' line (DEX save)</td>
        </tr>
        <tr>
        <td>Bronze</td>
        <td>Lightning</td>
        <td>5' by 30' line (DEX save)</td>
        </tr>
        <tr>
        <td>Copper</td>
        <td>Acid</td>
        <td>5' by 30' line (DEX save)</td>
        </tr>
        <tr>
        <td>Gold</td>
        <td>Fire</td>
        <td>15' cone (DEX save)</td>
        </tr>
        <tr>
        <td>Green</td>
        <td>Poison</td>
        <td>15' cone (CON save)</td>
        </tr>
        <tr>
        <td>Red</td>
        <td>Fire</td>
        <td>15' cone (DEX save)</td>
        </tr>
        <tr>
        <td>Silver</td>
        <td>Cold</td>
        <td>15' cone (CON save)</td>
        </tr>
        <tr>
        <td>White</td>
        <td>Cold</td>
        <td>15' cone (CON save)</td>
        </tr>
        </table>
        <ul>
        <li><strong>Damage Resistance.</strong> You have resistance to the damage type associated with your ancestry.</li>
        </ul>
        <ul>
        <li><strong>Languages.</strong> You can read, speak, and write Common and Draconic.</li>
        </ul>
        `,
        features: [
          {
            name: 'Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>You can use your action to exhale destructive energy. It deals damage in an area according to your ancestry. When you use your breath weapon, all creatures in the area must make a saving throw, the type of which is determined by your ancestry. The DC of this saving throw is 8 + your Constitution modifier + your proficiency bonus. A creature takes 2d6 damage on a failed save, and half as much damage on a successful one. The damage increase to 3d6 at 6th level, 4d6 at 11th, and 5d6 at 16th level. After using your breath weapon, you cannot use it again until you complete a short or long rest. <em><sup>HB</sup>Instead, you may use your breath weapon a number of times equal to your Constitution modifier. You regain expended uses on a short or long rest.</em></p>
            `,
          },
        ],
      },
      {
        title: 'Draconblood',
        description: `
          <p><strong><em>Draconbloods possess long tails and a knack for social manipulation. They remember the days when they were once mighty conquerors.</em></strong></p>
          <p><strong><em>A draconblood uses the dragonborn traits in the</em> Player's Handbook, <em>with the following traits replacing the</em> Ability Score Increase <em>and</em> Damage Resistance <em>traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 2, and your Charisma score increases by 1.</li>
          </ul>
        `,
        features: [
          {
            name: 'Forceful Presence',
            level: 0,
            isAbility: false,
            description: `
            <p>When you make a Intimidation or Persuasion check, you can do so with advantage once per long rest.</p>
            `,
          },
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
        ],
      },
      {
        title: 'Ravenite',
        description: `
          <p><strong><em>Ravenites have no tails and a hearty physique. They remember the days when they were slaves to the draconblood, as well as the day when they overthrew their masters.</em></strong></p>
          <p><strong><em>A ravenite uses the dragonborn traits in the</em> Player's Handbook, <em>with the following traits replacing the</em> Ability Score Increase <em>and</em> Damage Resistance <em>traits.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Strength score increases by 2, and your Constitution score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Darkvision.</strong> You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</li>
          </ul>
          <ul>
          <li><strong>Vengeful Assault.</strong> When you take damage from a creature in range of a weapon you are wielding, you can use your reaction to make an attack against that creature. You can do this once per short or long rest.</li>
          </ul>
        `,
        features: [
          {
            name: 'Vengeful Assault',
            level: 0,
            isAbility: true,
            description: `
            <p>When you take damage from a creature in range of a weapon you are wielding, you can use your reaction to make an attack against that creature. You can do this once per short or long rest.</p>
            `,
          },
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
        ],
      },
      {
        title: 'Chromatic',
        description: `
          <p><strong><em>Dragonborn with chromatic ancestry claim the raw elemental power of chromatic dragons. The vibrant colors of black, blue, green, red, and white dragons gleam in those dragonborn's scaled skin and in the deadly energy of their breath weapons. Theirs is the raw elemental fury of the volcano, of biting arctic winds, and of raging lightning storms, as well as the subtle whisper of swamp and forest, toxic and corrosive.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Increase one ability score by 2 and increase a different one by 1, or you increase three different scores by 1.</li>
          </ul>
          <ul>
          <li><strong>Type.</strong> You are a Humanoid.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> You are Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Chromatic Ancestry.</strong> You trace your ancestry to a chromatic dragon, granting you a special magical affinity. Choose one type of dragon from the Chromatic Ancestry table. This determines the damage type for your other traits as shown in the table.</li>
          </ul>
          <table class='table'>
          <tr>
          <th colspan="2">Chromatic Ancestry</th>
          </tr>
          <tr>
          <th>Dragon</th>
          <th>Damage Type</th>
          </tr>
          <tr>
          <td>Black</td>
          <td>Acid</td>
          </tr>
          <tr>
          <td>Blue</td>
          <td>Lightning</td>
          </tr>
          <tr>
          <td>Green</td>
          <td>Poison</td>
          </tr>
          <tr>
          <td>Red</td>
          <td>Fire</td>
          </tr>
          <tr>
          <td>White</td>
          <td>Cold</td>
          </tr>
          </table>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one other language that you and your DM agree is appropriate for the character.</li>
          </ul>
          `,
        features: [
          {
            name: 'Chromatic Warding',
            level: 0,
            isAbility: true,
            description: `
            <p>Starting at 5th level, as an action, you can channel your draconic energy to protect yourself. For 1 minute, you become immune to the damage type associated with your Chromatic Ancestry. Once you use this trait, you can’t do so again until you finish a long rest.</p>
            `,
          },
          {
            name: 'Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>When you take the Attack action on your turn, you can replace one of your attacks with an exhalation of magical energy in a 30-foot line that is 5 feet wide. Each creature in that area must make a Dexterity saving throw (DC = 8 + your Constitution modifier + your proficiency bonus). On a failed save, the creature takes 1d10 damage of the type associated with your Chromatic Ancestry. On a successful save, it takes half as much damage. This damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10). You can use your Breath Weapon a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
            `,
          },
          {
            name: 'Draconic Resistance',
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to the damage type associated with your Chromatic Ancestry.</p>
            `,
          },
        ],
      },
      {
        title: 'Metallic',
        description: `
          <p><strong><em>Dragonborn with metallic ancestry lay claim to the tenacity of metallic dragons — brass, bronze, copper, gold, and silver — whose hues glint in their scales. Theirs is the fire of hearth and forge, the cold of high mountain air, the spark of inspiration, and the scouring touch of acid that purifies.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Increase one ability score by 2 and increase a different one by 1, or you increase three different scores by 1.</li>
          </ul>
          <ul>
          <li><strong>Type.</strong> You are a Humanoid.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> You are Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Metallic Ancestry.</strong> You trace your ancestry to a metallic dragon, granting you a special magical affinity. Choose one type of dragon from the Metallic Ancestry table. This determines the damage type for your other traits as shown in the table.</li>
          </ul>
          <table class='table'>
          <tr>
          <th colspan="2">Metallic Ancestry</th>
          </tr>
          <tr>
          <th>Dragon</th>
          <th>Damage Type</th>
          </tr>
          <tr>
          <td>Brass</td>
          <td>Fire</td>
          </tr>
          <tr>
          <td>Bronze</td>
          <td>Lightning</td>
          </tr>
          <tr>
          <td>Copper</td>
          <td>Acid</td>
          </tr>
          <tr>
          <td>Gold</td>
          <td>Fire</td>
          </tr>
          <tr>
          <td>Silver</td>
          <td>Cold</td>
          </tr>
          </table>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one other language that you and your DM agree is appropriate for the character.</li>
          </ul>
        `,
        features: [
          {
            name: 'Draconic Resistance',
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to the damage type associated with your Metallic Ancestry.</p>
            `,
          },
          {
            name: 'Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>When you take the Attack action on your turn, you can replace one of your attacks with an exhalation of magical energy in a 15-foot cone. Each creature in that area must make a Dexterity saving throw (DC = 8 + your Constitution modifier + your proficiency bonus). On a failed save, the creature takes 1d10 damage of the type associated with your Metallic Ancestry. On a successful save, it takes half as much damage. This damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10). You can use your Breath Weapon a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
            `,
          },
          {
            name: 'Metallic Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>At 5th level, you gain a second breath weapon. When you take the Attack action on your turn, you can replace one of your attacks with an exhalation in a 15-foot cone. The save DC for this breath is 8 + your Constitution modifier + your proficiency bonus. Whenever you use this trait, choose one:
            <ul>
            <li><strong>Enervating Breath.</strong> Each creature in the cone must succeed on a Constitution saving throw or become incapacitated until the start of your next turn.</li>
            <li><strong>Repulsion Breath.</strong> Each creature in the cone must succeed on a Strength saving throw or be pushed 20 feet away from you and be knocked prone.</li>
            </ul>
            Once you use your Metallic Breath Weapon, you can’t do so again until you finish a long rest.</p>
            `,
          },
        ],
      },
      {
        title: 'Gem',
        description: `
          <p><strong><em>Gem dragonborn partake of the heritage of gem dragons, who claim to be heirs of Sardior, the Ruby Dragon. The colors and mysterious powers of gem dragons — amethyst, crystal, emerald, sapphire, and topaz — gleam in these dragonborn’s scaled skin and course through their veins. Theirs are the wonders of the mind, the force of will, the brilliant light of insight, and the resounding echo of discovery — but also the desiccation of despair.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Increase one ability score by 2 and increase a different one by 1, or you increase three different scores by 1.</li>
          </ul>
          <ul>
          <li><strong>Type.</strong> You are a Humanoid.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> You are Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Gem Ancestry.</strong> You trace your ancestry to a Gem dragon, granting you a special magical affinity. Choose one type of dragon from the Gem Ancestry table. This determines the damage type for your other traits as shown in the table.</li>
          </ul>
          <table class='table'>
          <tr>
          <th colspan="2">Gem Ancestry</th>
          </tr>
          <tr>
          <th>Dragon</th>
          <th>Damage Type</th>
          </tr>
          <tr>
          <td>Amethyst</td>
          <td>Force</td>
          </tr>
          <tr>
          <td>Crystal</td>
          <td>Radiant</td>
          </tr>
          <tr>
          <td>Emerald</td>
          <td>Psychic</td>
          </tr>
          <tr>
          <td>Sapphire</td>
          <td>Thunder</td>
          </tr>
          <tr>
          <td>Topaz</td>
          <td>Necrotic</td>
          </tr>
          </table>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one other language that you and your DM agree is appropriate for the character.</li>
          </ul>
        `,
        features: [
          {
            name: 'Draconic Resistance',
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to the damage type associated with your Gem Ancestry.</p>
            `,
          },
          {
            name: 'Psionic Mind',
            level: 0,
            isAbility: false,
            description: `
            <p>You can telepathically speak to any creature you can see within 30 feet of you. You don’t need to share a language with the creature, but the creature must be able to understand at least one language.</p>
            `,
          },
          {
            name: 'Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>When you take the Attack action on your turn, you can replace one of your attacks with an exhalation of magical energy in a 15-foot cone. Each creature in that area must make a Dexterity saving throw (DC = 8 + your Constitution modifier + your proficiency bonus). On a failed save, the creature takes 1d10 damage of the type associated with your Gem Ancestry. On a successful save, it takes half as much damage. This damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10). You can use your Breath Weapon a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
            `,
          },
          {
            name: 'Gem Flight',
            level: 0,
            isAbility: true,
            description: `
              <p>Starting at 5th level, you can use a bonus action to manifest spectral wings on your body. These wings last for 1 minute. For the duration, you gain a flying speed equal to your walking speed and can hover. Once you use this trait, you can’t do so again until you finish a long rest.</p>
              `,
          },
        ],
      },
      {
        title: 'Chromatic',
        description: `
          <p>Source: Unearthed Arcana 78 - Draconic Options</p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Increase one ability score by 2 and increase a different one by 1, or you increase three different scores by 1.</li>
          </ul>
          <ul>
          <li><strong>Type.</strong> You are a Humanoid.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> You are Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Chromatic Ancestry.</strong> You trace your ancestry to a chromatic dragon, granting you a special magical affinity. Choose one type of dragon from the Chromatic Ancestry table. This determines the damage type for your other traits as shown in the table.</li>
          </ul>
          <table class='table'>
          <tr>
          <th colspan="2">Chromatic Ancestry</th>
          </tr>
          <tr>
          <th>Dragon</th>
          <th>Damage Type</th>
          </tr>
          <tr>
          <td>Black</td>
          <td>Acid</td>
          </tr>
          <tr>
          <td>Blue</td>
          <td>Lightning</td>
          </tr>
          <tr>
          <td>Green</td>
          <td>Poison</td>
          </tr>
          <tr>
          <td>Red</td>
          <td>Fire</td>
          </tr>
          <tr>
          <td>White</td>
          <td>Cold</td>
          </tr>
          </table>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one other language that you and your DM agree is appropriate for the character.</li>
          </ul>
        `,
        features: [
          {
            name: 'Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>When you take the Attack action, you can replace one of your attacks with an exhalation of a magical energy in a 30-foot line that is 5 feet wide. Each creature in the area must make a Dexterity saving throw against a DC equal to 8 + your Constitution modifier + your proficiency bonus. A creature takes 2d8 damage of the type associated with your Chromatic Ancestry on a failed save, and half as much damage on a successful one. This damage increases by 1d8 when you reach 5th level (3d8), 11th level (4d8), and 17th level (5d8). You can use this trait a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
            `,
          },
          {
            name: 'Draconic Resistance',
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to the damage type associated with your Chromatic Ancestry.</p>
            `,
          },
          {
            name: 'Chromatic Warding',
            level: 3,
            isAbility: true,
            description: `
            <p>Starting at 3rd level, as an action, you can channel your draconic energies to protect yourself. For 10 minutes, you become immune to the damage type associated with your Chromatic Ancestry. Once you use this trait, you can’t do so again until you finish a long rest.</p>
            `,
          },
        ],
      },
      {
        title: 'Metallic',
        description: `
          <p>Source: Unearthed Arcana 78 - Draconic Options</p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Increase one ability score by 2 and increase a different one by 1, or you increase three different scores by 1.</li>
          </ul>
          <ul>
          <li><strong>Type.</strong> You are a Humanoid.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> You are Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Metallic Ancestry.</strong> You trace your ancestry to a metallic dragon, granting you a special magical affinity. Choose one type of dragon from the Metallic Ancestry table. This determines the damage type for your other traits as shown in the table.</li>
          </ul>
          <table class='table'>
          <tr>
          <th colspan="2">Metallic Ancestry</th>
          </tr>
          <tr>
          <th>Dragon</th>
          <th>Damage Type</th>
          </tr>
          <tr>
          <td>Brass</td>
          <td>Fire</td>
          </tr>
          <tr>
          <td>Bronze</td>
          <td>Lightning</td>
          </tr>
          <tr>
          <td>Copper</td>
          <td>Acid</td>
          </tr>
          <tr>
          <td>Gold</td>
          <td>Fire</td>
          </tr>
          <tr>
          <td>Silver</td>
          <td>Cold</td>
          </tr>
          </table>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one other language that you and your DM agree is appropriate for the character.</li>
          </ul>
        `,
        features: [
          {
            name: 'Draconic Resistance',
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to the damage type associated with your Metallic Ancestry.</p>
            `,
          },
          {
            name: 'Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>When you take the Attack action, you can replace one of your attacks with an exhalation of a magical energy in a 15-foot line that is 5 feet wide. Each creature in the area must make a Dexterity saving throw against a DC equal to 8 + your Constitution modifier + your proficiency bonus. A creature takes 2d8 damage of the type associated with your Metallic Ancestry on a failed save, and half as much damage on a successful one. This damage increases by 1d8 when you reach 5th level (3d8), 11th level (4d8), and 17th level (5d8). You can use this trait a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
            `,
          },
          {
            name: 'Metallic Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>At 3rd level you gain a second breath weapon. When you take the Attack action, you can replace one of your attacks with an exhalation of a magical gas in a 15-foot cone. The save DC for this breath is 8 + your Constitution modifier + your proficiency bonus. When you use this ability, choose one:
            <ul>
            <li>Each creature in the area must succeed on a Strength saving throw or be pushed 20 feet away from you and be knocked prone.</li>
            <li>Each creature in the area must succeed on a Constitution saving throw or become incapacitated until the start of your next turn.</li>
            </ul>
            Once you use your Metallic Breath Weapon, you can’t do so again until you finish a long rest.</p>
            `,
          },
        ],
      },
      {
        title: 'Gem',
        description: `
          <p>Source: Unearthed Arcana 78 - Draconic Options</p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Increase one ability score by 2 and increase a different one by 1, or you increase three different scores by 1.</li>
          </ul>
          <ul>
          <li><strong>Type.</strong> You are a Humanoid.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> You are Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Gem Ancestry.</strong> You trace your ancestry to a Gem dragon, granting you a special magical affinity. Choose one type of dragon from the Gem Ancestry table. This determines the damage type for your other traits as shown in the table.</li>
          </ul>
          <table class='table'>
          <tr>
          <th colspan="2">Gem Ancestry</th>
          </tr>
          <tr>
          <th>Dragon</th>
          <th>Damage Type</th>
          </tr>
          <tr>
          <td>Amethyst</td>
          <td>Force</td>
          </tr>
          <tr>
          <td>Crystal</td>
          <td>Radiant</td>
          </tr>
          <tr>
          <td>Emerald</td>
          <td>Psychic</td>
          </tr>
          <tr>
          <td>Sapphire</td>
          <td>Thunder</td>
          </tr>
          <tr>
          <td>Topaz</td>
          <td>Necrotic</td>
          </tr>
          </table>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and one other language that you and your DM agree is appropriate for the character.</li>
          </ul>
          </div>
        `,
        features: [
          {
            name: 'Draconic Resistance',
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to the damage type associated with your Gem Ancestry.</p>
            `,
          },
          {
            name: 'Psionic Mind',
            level: 0,
            isAbility: false,
            description: `
            <p>You can telepathically speak to any creature you can see within 30 feet of you. You don’t need to share a language with the creature, but the creature must be able to understand at least one language.</p>
            `,
          },
          {
            name: 'Breath Weapon',
            level: 0,
            isAbility: true,
            description: `
            <p>When you take the Attack action on your turn, you can replace one of your attacks with an exhalation of magical energy in a 15-foot cone. Each creature in that area must make a Dexterity saving throw (DC = 8 + your Constitution modifier + your proficiency bonus). On a failed save, the creature takes 1d10 damage of the type associated with your Gem Ancestry. On a successful save, it takes half as much damage. This damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10). You can use your Breath Weapon a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest.</p>
            `,
          },
          {
            name: 'Gem Flight',
            level: 5,
            isAbility: true,
            description: `
              <p>Starting at 5th level, you can use a bonus action to manifest spectral wings on your body. These wings last for 1 minute. For the duration, you gain a flying speed equal to your walking speed and can hover. Once you use this trait, you can’t do so again until you finish a long rest.</p>
              `,
          },
        ],
      },
    ],
  };

  private tiefling: any = {
    title: 'tiefling',
    content: [
      {
        title: "Player's Handbook",
        description: `
          <p><em><strong>To be greeted with stares and whispers, to suffer violence and insult on the street, to see mistrust and fear in every eye: this is the lot of the tiefling. And to twist the knife, tieflings know that this is because a pact struck generations ago infused the essence of Asmodeus, overlord of the Nine Hells (and many of the other powerful devils serving under him) into their bloodline. Their appearance and their nature are not their fault but the result of an ancient sin, for which they and their children and their children's children will always be held accountable.</strong></em></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Charisma score increases by 2.</li>
          </ul>
          <ul>
          <li><strong>Age.</strong> Tieflings mature at the same rate as humans but live a few years longer.</li>
          </ul>
          <ul>
          <li><strong>Alignment.</strong> Tieflings might not have an innate tendency toward evil, but many of them end up there. Evil or not, an independent nature inclines many tieflings toward a chaotic alignment.</li>
          </ul>
          <ul>
          <li><strong>Size.</strong> Tieflings are about the same size and build as humans. Your size is Medium.</li>
          </ul>
          <ul>
          <li><strong>Speed.</strong> Your base walking speed is 30 feet.</li>
          </ul>
          <ul>
          <li><strong>Languages.</strong> You can speak, read, and write Common and Infernal.</li>
          </ul>
          `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see in dim light within 60ft. of you as if it were bright light, and in darkness as if it were dim light. You can't discern colors in darkness, only shades of grey.</p>
            `,
          },
          {
            name: 'Hellish Resistance',
            level: 0,
            isAbility: false,
            description: `
            <p>You have resistance to fire damage.</p>
            `,
          },
        ],
      },
      {
        title: 'Bloodline of Asmodeus',
        description: `
          <p><strong><em>The tieflings connected to Nessus command the power of fire and darkness, guided by a keener than normal intellect, as befits those linked to Asmodeus himself.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Infernal Legacy.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:thaumaturgy">Thaumaturgy</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:hellish-rebuke">Hellish Rebuke</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:darkness">Darkness</a> spell once. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
          </ul>
        `,
      },
      {
        title: 'Bloodline of Baalzebul',
        description: `
          <p><strong><em>The crumbling realm of Maladomini is ruled by Baalzebul, who excels at corrupting those whose minor sins can be transformed into acts of damnation. Tieflings linked to this archdevil can corrupt others both physically and psychically.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Legacy of Maladomini.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:thaumaturgy">Thaumaturgy</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:ray-of-sickness">Ray of Sickness</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:crown-of-madness">Crown of Madness</a> spell once. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
          </ul>
        `,
      },
      {
        title: 'Bloodline of Dispater',
        description: `
          <p><strong><em>The great city of Dis occupies most of Hell's second layer. It is a place where secrets are uncovered and shared with the highest bidder, making tieflings tied to Dispater excellent spies and infiltrators.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Legacy of Dis.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:thaumaturgy">Thaumaturgy</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:disguise-self">Disguise Self</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:detect-thoughts">Detect Thoughts</a> spell once. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
          </ul>
        `,
      },
      {
        title: 'Bloodline of Fierna',
        description: `
          <p><strong><em>A master manipulator, Fierna grants tieflings tied to her forceful personalities.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Wisdom score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Legacy of Phlegethos.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:friends">Friends</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:charm-person">Charm Person</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:suggestion">Suggestion</a> spell once. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
          </ul>
        `,
      },
      {
        title: 'Bloodline of Glasya',
        description: `
          <p><strong><em>Glasya, Hell's criminal mastermind, grants her tiefiings magic that is useful for committing heists.</em></strong></p>
          <ul>
          <li><strong>Ability Score Increase.</strong> Your Dexterity score increases by 1.</li>
          </ul>
          <ul>
          <li><strong>Legacy of Malbolge.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:minor-illusion">Minor Illusion</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:disguise-self">Disguise Self</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:invisibility">Invisibility</a> spell once as a 2nd-level spell. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
          </ul>
        `,
      },
      {
        title: 'Bloodline of Levistus',
        description: `
        <p><strong><em>Frozen Stygia is ruled by Levistus, an archdevil known for offering bargains to those who face an inescapable doom.</em></strong></p>
        <ul>
        <li><strong>Ability Score Increase.</strong> Your Constitution score increases by 1.</li>
        </ul>
        <ul>
        <li><strong>Legacy of Stygia.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:ray-of-frost">Ray of Frost</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:armor-of-agathys">Armor of Agathys</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:darkness">Darkness</a> spell once. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
        </ul>
        `,
      },
      {
        title: 'Bloodline of Mammon',
        description: `
        <p><strong><em>The great miser Mammon loves coins above all else. Tieflings tied to him excel at gathering and safeguarding wealth.</em></strong></p>
        <ul>
        <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 1.</li>
        </ul>
        <ul>
        <li><strong>Legacy of Minauros.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:mage-hand">Mage Hand</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:tensers-floating-disk">Tenser's Floating Disk</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:arcane-lock">Arcane Lock</a> spell once. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
        </ul>
      `,
      },
      {
        title: 'Bloodline of Mephistopheles',
        description: `
        <p><strong><em>In the frozen realm of Cania, Mephistopheles offers arcane power to those who entreat with him. Tieflings linked to him master some arcane magic.</em></strong></p>
        <ul>
        <li><strong>Ability Score Increase.</strong> Your Intelligence score increases by 1.</li>
        </ul>
        <ul>
        <li><strong>Legacy of Cania.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:mage-hand">Mage Hand</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:burning-hands">Burning Hands</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:flame-blade">Flame Blade</a> spell once as a 3rd-level spell. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
        </ul>
        `,
      },
      {
        title: 'Bloodline of Zariel',
        description: `
        <p><strong><em>Tieflings with a blood tie to Zariel are stronger than the typical tiefling and receive magical abilities that aid them in battle.</em></strong></p>
        <ul>
        <li><strong>Ability Score Increase.</strong> Your Strength score increases by 1.</li>
        </ul>
        <ul>
        <li><strong>Legacy of Avernus.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:thaumaturgy">Thaumaturgy</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:searing-smite">Searing Smite</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:branding-smite">Branding Smite</a> spell once as a 3rd-level spell. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells.</li>
        </ul>
      `,
      },
      {
        title: 'Variant Tiefling',
        description: `
        <h2 id="toc12"><span>Variant Tiefling</span></h2>
        <p><strong><em>Since not all tieflings are of the blood of Asmodeus, some have traits that differ from those in the</em> Player's Handbook. <em>The Dungeon Master may permit the following variants for your tiefling character, although Devil's Tongue, Hellfire, and Winged are mutually exclusive.</em></strong></p>
        <ul>
        <li><strong>Appearance.</strong> Your tiefling might not look like other tieflings. Rather than having the physical characteristics described in the <em>Player's Handbook</em>, choose 1d4 + 1 of the following features: small horns; fangs or sharp teeth; a forked tongue; catlike eyes; six fingers on each hand; goat-like legs; cloven hoofs; a forked tail; leathery or scaly skin; red or dark blue skin; cast no shadow or reflection; exude a smell of brimstone.</li>
        </ul>
        <ul>
        <li><strong>Feral.</strong> Your Intelligence score increases by 1, and your Dexterity score increases by 2. This trait replaces the Ability Score Increase trait</li>
        </ul>
        <ul>
        <li><strong>Devil's Tongue.</strong> You know the <a href="http://dnd5e.wikidot.com/spell:vicious-mockery">Vicious Mockery</a> cantrip. Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:charm-person">Charm Person</a> spell once as a 2nd-level spell. Once you reach 5th level, you can also cast the <a href="http://dnd5e.wikidot.com/spell:enthrall">Enthrall</a> spell once. You must finish a long rest to cast these spells again with this trait. Charisma is your spellcasting ability for these spells. This trait replaces the Infernal Legacy trait</li>
        </ul>
        <ul>
        <li><strong>Hellfire.</strong> Once you reach 3rd level, you can cast the <a href="http://dnd5e.wikidot.com/spell:burning-hands">Burning Hands</a> spell once as a 2nd-level spell. This trait replaces the <a href="http://dnd5ewikidot.com/spell:hellish-rebuke">Hellish Rebuke</a> spell of the Infernal Legacy trait.</li>
        </ul>
        `,
        features: [
          {
            name: 'Winged',
            level: 0,
            isAbility: false,
            description: `
            <p>You have bat-like wings sprouting from your shoulders. You have a flying speed of 30 feet while you aren’t wearing heavy armor. This trait replaces the Infernal Legacy trait.</p>
            `,
          },
        ],
      },
      {
        title: 'Abyssal Tiefling',
        description: `
        <p>Source: Unearthed Arcana 11 - That Old Black Magic</p>
        <p><strong><em>All abyssal tieflings trace their bloodline to the demons of the Abyss. These tieflings have the following additional features.</em></strong></p>
        <ul>
        <li><strong>Ability Score Increase.</strong> Your Constitution score increases by 1.</li>
        </ul>
        <ul>
        <li><strong>Abyssal Arcana.</strong> Each time you finish a long rest, you gain the ability to cast cantrips and spells randomly determined from a short list. At 1st level, you can cast a cantrip. When you reach 3rd level, you can also cast a 1st-level spell. At 5th level, you can cast a 2nd-level spell.
        <ul>
        <li>You can cast a spell gained from this trait only once until you complete your next long rest. You can cast a cantrip gained from this trait at will, as normal. For 1st-level spells whose effect changes if cast using a spell slot of 2nd level or higher, you cast the spell as if using a 2nd-level slot. Spells of 2nd level are cast as if using a 2nd-level slot.</li>
        <li>At the end of each long rest, you lose the cantrips and spells previously granted by this feature, even if you did not cast them. You replace those cantrips and spells by rolling for new ones on the Abyssal Arcana Spells table. Roll separately for each cantrip and spell. If you roll the same spell or cantrip you gained at the end of your previous long rest, roll again until you get a different result.</li>
        </ul>
        </li>
        </ul>
        <ul>
        <li><strong>Abyssal Fortitude.</strong> Your hit point maximum increases by half your level (minimum 1).</li>
        </ul>
        <ul>
        <li><strong>Languages.</strong> You can speak, read, and write Abyssal.</li>
        </ul>
        <table class='table'>
        <tr>
        <th colspan="4">Abyssal Arcana Spells</th>
        </tr>
        <tr>
        <th>d6</th>
        <th>1st Level</th>
        <th>3rd Level</th>
        <th>5th Level</th>
        </tr>
        <tr>
        <td>1</td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:dancing-lights">Dancing Lights</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:burning-hands">Burning Hands</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:alter-self">Alter Self</a></em></td>
        </tr>
        <tr>
        <td>2</td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:true-strike">True Strike</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:charm-person">Charm Person</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:darkness">Darkness</a></em></td>
        </tr>
        <tr>
        <td>3</td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:light">Light</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:magic-missile">Magic Missile</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:invisibility">Invisibility</a></em></td>
        </tr>
        <tr>
        <td>4</td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:message">Message</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:cure-wounds">Cure Wounds</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:levitate">Levitate</a></em></td>
        </tr>
        <tr>
        <td>5</td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:spare-the-dying">Spare the Dying</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:tashas-hideous-laughter">Tasha's Hideous Laughter</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:mirror-image">Mirror Image</a></em></td>
        </tr>
        <tr>
        <td>6</td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:prestidigitation">Prestidigitation</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:thunderwave">Thunderwave</a></em></td>
        <td><em><a href="http://dnd5e.wikidot.com/spell:spider-climb">Spider Climb</a></em></td>
        </tr>
        </table>
        </div>
        `,
      },
    ],
  };

  // Other Species

  private eladrin: any = {
    title: 'eladrin',
    content: [
      {
        title: '',
        description: `
          <p>Eladrin are elves of the Feywild, a realm of perilous beauty and boundless magic. Using that magic, eladrin can step from one place to another in the blink of an eye, and each eladrin resonates with emotions captured in the Feywild in the form of seasons — affinities that affect the eladrin’s mood and appearance. An eladrin’s season can change, though some remain in one season forever. Like other elves, eladrin can live to be over 750 years old.</p>
          <h4>Eladrin Seasons</h4>
          <ul>
            <li><strong>Autumn:</strong> peace and goodwill, when summer's harvest is shared with all.</li>
            <li><strong>Winter:</strong> contemplation and dolor, when the vibrant energy of the world slumbers.</li>
            <li><strong>Spring:</strong> cheerfulness and celebration, marked by merriment and hope as winter's sorrow passes.</li>
            <li><strong>Summer:</strong> boldness and aggression, a time of unfettered energy and calls to action.</li>
          </ul>
          <h4>Eladrin Characteristics</h4>
          <p><b>Ability Score Increase:</b> When determining your character’s ability scores, increase one score by 2 and increase a different score by 1, or increase three different scores by 1. You can't raise any of your scores above 20.</p>    
          <p><b>Creature Type:</b> You are a Humanoid. You are also considered an elf for any prerequisite or effect that requires you to be an elf.</p>
          <p><b>Size:</b> You are Medium.</p>
          <p><b>Speed:</b> Your walking speed is 30 feet.</p>     
          <p><b>Keen Senses:</b> You have proficiency in the Perception skill.</p>
          <ul>
            <li>Whenever you finish this trance, you can change your season, and you can gain two proficiencies that you don’t have, each one with a weapon or a tool of your choice selected from the Player’s Handbook. You mystically acquire these proficiencies by drawing them from shared elven memory, and you retain them until you finish your next long rest.
          </li>
          </ul>
          <p><b>Languages:</b> Your character can speak, read, and write Common and one other language that you and your DM agree is appropriate for the character. The Player’s Handbook offers a list of languages to choose from. The DM is free to modify that list for a campaign.</p>
        `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see in dim light within 60 feet of you as if it were bright light, and in darkness as if it were dim light. You can't discern color in darkness, only shades of gray.</p>
            `,
          },
          {
            name: 'Fey Ancestry',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws you make to avoid or end the charmed condition on yourself.</p>
            `,
          },
          {
            name: 'Trance',
            level: 0,
            isAbility: false,
            description: `
            <p>You don’t need to sleep, and magic can’t put you to sleep. You can finish a long rest in 4 hours if you spend those hours in a trancelike meditation, during which you retain consciousness.</p>
            `,
          },
          {
            name: 'Fey Step',
            level: 0,
            isAbility: true,
            description: `
          <p>As a bonus action, you can magically teleport up to 30 feet to an unoccupied space you can see. You can use this trait a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest. When you reach 3rd level, your Fey Step gains an additional effect based on your season; if the effect requires a saving throw, the DC equals 8 + your proficiency bonus + your Intelligence, Wisdom, or Charisma modifier (choose when you select
          <p>When you reach 3rd level, your Fey Step gains an additional effect based on your season; if the effect requires a saving throw, the DC equals 8 + your proficiency bonus + your Intelligence, Wisdom, or Charisma modifier (choose when you select this race):</p>
          <ul>
            <li><strong>Autumn:</strong> Immediately after you use your Fey Step, up to two creatures of your choice that you can see within 10 feet of you must succeed on a Wisdom saving throw or be charmed by you for 1 minute, or until you or your companions deal any damage to the creatures.</li>
            <li><strong>Winter:</strong> When you use your Fey Step, one creature of your choice that you can see within 5 feet of you before you teleport must succeed on a Wisdom saving throw or be frightened of you until the end of your next turn.</li>
            <li><strong>Spring:</strong> When you use your Fey Step, you can touch one willing creature within 5 feet of you. That creature then teleports instead of you, appearing in an unoccupied space of your choice that you can see within 30 feet of you.</li>
            <li><strong>Summer:</strong> Immediately after you use your Fey Step, each creature of your choice that you can see within 5 feet of you takes fire damage equal to your proficiency bonus.</li>
          </ul>
        `,
          },
        ],
      },
    ],
  };

  private halfElfDetection: any = {
    title: 'halfElfDetection',
    content: [
      {
        title: '',
        description: `
          <p>Walking in two worlds but truly belonging to neither, half-elves combine what some say are the best qualities of their elf and human parents: human curiosity, inventiveness, and ambition tempered by the refined senses, love of nature, and artistic tastes of the elves.</p>
    <p><b>Ability Score Increase:</b> Your Charisma score increases by 2, and two other ability scores of your choice increase by 1.</p>
    <p><b>Creature Type:</b> You are a Humanoid. You are also considered an elf for any prerequisite or effect that requires you to be an elf.</p>
    <p><b>Size:</b> You are Medium.</p>
    <p><b>Speed:</b> Your walking speed is 30 feet.</p>
    <p><b>Skill Versatility:</b> You gain proficiency in two skills of your choice.</p>
    <p><b>Languages:</b> Your character can speak, read, and write Common, Elvish, and one extra language of your choice.</p>
    <p><b>Magical Detection:</b> You can cast the Detect Magic and the Detect Poison and Disease spells with this trait. Starting at 3rd level, you can also cast the See Invisibility spell with it. Once you cast either spell with this trait, you can't cast that spell again until you finish a Long Rest. Intelligence is your Spellcasting Ability for these spells, and you don't require material components for them.</p>
    <p><b>Spells of the Mark:</b> If you have the Spellcasting or Pact Magic class feature, the spells on the Mark of Detection Spells table are added to the spell list of your Spellcasting class.</p>
    <p><b>Mark of Detection Spells</b></p>
    <table class='table'>
      <tr>
        <th>Spell Level</th>
        <th>Spells</th>
      </tr>
      <tr>
        <td>1st</td>
        <td>Detect Magic, Detect Poison and Disease</td>
      </tr>
      <tr>
        <td>2nd</td>
        <td>See Invisibility</td>
      </tr>
      <tr>
        <td>3rd</td>
        <td>Clairvoyance, Tongues</td>
      </tr>
      <tr>
        <td>4th</td>
        <td>Arcane Eye, Locate Creature</td>
      </tr>
      <tr>
        <td>5th</td>
        <td>Legend Lore, Rary's Telepathic Bond</td>
      </tr>
    </table>
    `,
        features: [
          {
            name: 'Darkvision',
            level: 0,
            isAbility: false,
            description: `
            <p>You can see in dim light within 60ft. of you as if it were bright light, and in darkness as if it were dim light. You can't discern colors in darkness, only shades of grey.</p>
            `,
          },
          {
            name: 'Fey Ancestry',
            level: 0,
            isAbility: false,
            description: `
            <p>You have advantage on saving throws you make to avoid or end the charmed condition on yourself.</p>
            `,
          },
          {
            name: 'Trance',
            level: 0,
            isAbility: false,
            description: `
            <p>You don’t need to sleep, and magic can’t put you to sleep. You can finish a long rest in 4 hours if you spend those hours in a trancelike meditation, during which you retain consciousness.</p>
            `,
          },
          {
            name: 'Deductive Intuition',
            level: 0,
            isAbility: false,
            description: `
            <p>Whenever you make a Intelligence (Investigation) or a Wisdom (Insight) check, you can roll a d4 and add the number rolled to the total ability check.</p>
            `,
          },
        ],
      },
    ],
  };

  private notImplementedYet: any = {
    title: 'Not Implemented Yet',
    description: `
    `,
    abilities: [],
  };
}
