import { Injectable } from '@angular/core';
import { SubclassData } from 'src/interfaces/interfaces';

@Injectable({
  providedIn: 'root',
})
export class SubclassService {
  public getSubclassDetails(subclass: string): any {
    switch (subclass) {
      // FIGHTER
      case 'echoKnight':
        return this.echoKnight;
      // CLERIC
      case 'peaceDomain':
        return this.peaceDomain;
      // PALADIN
      case 'vengeance':
        return this.vengeance;
      // MONK
      case 'wayOfShadows':
        return this.wayOfShadows;
      // RANGER
      case 'beastMaster':
        return this.beastMaster;
      default:
        return this.notImplementedYet;
    }
  }

  public getAvailableSubclassNames(className: string): string[] {
    switch (className) {
      case 'barbarian':
        return [];
      case 'bard':
        return [];
      case 'cleric':
        return ['peaceDomain'];
      case 'druid':
        return [];
      case 'fighter':
        return ['echoKnight'];
      case 'monk':
        return ['wayOfShadows'];
      case 'paladin':
        return ['vengeance'];
      case 'ranger':
        return ['beastMaster'];
      case 'rogue':
        return [];
      case 'sorcerer':
        return [];
      case 'warlock':
        return [];
      case 'wizard':
        return [];
      default:
        return [];
    }
  }

  // BARBARIAN

  // BARD

  // CLERIC
  private peaceDomain: SubclassData = {
    title: 'Peace Domain',
    description: `
      <p>The balm of peace thrives at the heart of healthy communities, between friendly nations, and in the souls of the kindhearted. The gods of peace inspire people of all sorts to resolve conflict and to stand up against those forces that try to prevent peace from flourishing. See the Peace Deities table for a list of some of the gods associated with this domain.</p>
      <p>Clerics of the Peace Domain preside over the signing of treaties, and they are often asked to arbitrate in disputes. These clerics' blessings draw people together and help them shoulder one another's burdens, and the clerics' magic aids those who are driven to fight for the way of peace.</p>
    `,
    features: [
      {
        name: 'Implement of Peace',
        level: 1,
        description: `
          <p>When you choose this domain at 1st level, you gain proficiency in the Insight, Performance, or Persuasion skill (your choice).</p>
        `,
      },
      {
        name: 'Emboldening Bond',
        level: 1,
        description: `
          <p>Starting at 1st level, you can forge an empowering bond among people who are at peace with one another. As an action, you choose a number of willing creatures within 30 feet of you (this can include yourself) equal to your proficiency bonus. You create a magical bond among them for 10 minutes or until you use this feature again. While any bonded creature is within 30 feet of another, the creature can roll a d4 and add the number rolled to an attack roll, an ability check, or a saving throw it makes. Each creature can add the d4 no more than once per turn.</p>
          <p>You can use this feature a number of times equal to your proficiency bonus, and you regain all expended uses when you finish a long rest. </p>
        `,
        ability: '',
      },
      {
        name: 'Channel Divinity: Balm of Peace',
        level: 2,
        description: `
          <p>Starting at 2nd level, you can use your Channel Divinity to make your very presence a soothing balm. As an action, you can move up to your speed, without provoking opportunity attacks, and when you move within 5 feet of any other creature during this action, you can restore a number of hit points to that creature equal to 2d6 + your Wisdom modifier (minimum of 1 hit point). A creature can receive this healing only once whenever you take this action.</p>
        `,
        ability: '',
      },
      {
        name: 'Protective Bond',
        level: 6,
        description: `
          <p>Beginning at 6th level, the bond you forge between people helps them protect each other. When a creature affected by your Emboldening Bond feature is about to take damage, a second bonded creature within 30 feet of the first can use its reaction to teleport to an unoccupied space within 5 feet of the first creature. The second creature then takes all the damage instead.</p>
        `,
        ability: '',
      },
      {
        name: 'Potent Spellcasting',
        level: 8,
        description: `
          <p>At 8th level, you add your Wisdom modifier to the damage you deal with any cleric cantrip.</p>
        `,
      },
      {
        name: 'Expansive Bond',
        level: 17,
        description: `
          <p>At 17th level, the benefits of your Emboldening Bond and Protective Bond features now work when the creatures are within 60 feet of each other. Moreover, when a creature uses Protective Bond to take someone else's damage, the creature has resistance to that damage.</p>
        `,
      },
    ],
  };

  // DRUID

  // FIGHTER
  private echoKnight: SubclassData = {
    title: 'Echo Knight',
    description: `
    <p>A mysterious and feared frontline warrior of the Kryn Dynasty, the Echo Knight has mastered the art of using dunamis to summon the fading shades of unrealized timelines to aid them in battle. Surrounded by echoes of their own might, they charge into the fray as a cycling swarm of shadows and strikes.</p>
    `,
    features: [
      {
        name: 'Manifest Echo',
        level: 3,
        description: `
          <p>At 3rd level, you can use a bonus action to magically manifest an echo of yourself in an unoccupied space you can see within 15 feet of you. This echo is a magical, translucent, gray image of you that lasts until it is destroyed, until you dismiss it as a bonus action, until you manifest another echo, or until you're incapacitated.</p>
          <p>Your echo has AC 14 + your proficiency bonus, 1 hit point, and immunity to all conditions. If it has to make a saving throw, it uses your saving throw bonus for the roll. It is the same size as you, and it occupies its space. On your turn, you can mentally command the echo to move up to 30 feet in any direction (no action required). If your echo is ever more than 30 feet from you at the end of your turn, it is destroyed.</p>
          <ul>
          <li>As a bonus action, you can teleport, magically swapping places with your echo at a cost of 15 feet of your movement, regardless of the distance between the two of you.</li>
          </ul>
          <ul>
          <li>When you take the Attack action on your turn, any attack you make with that action can originate from your space or the echo's space. You make this choice for each attack.</li>
          </ul>
          <ul>
          <li>When a creature that you can see within 5 feet of your echo moves at least 5 feet away from it, you can use your reaction to make an opportunity attack against that creature as if you were in the echo's space.</li>
          </ul>
        `,
        ability: '',
      },
      {
        name: 'Unleash Incarnation',
        level: 3,
        description: `
          <p>At 3rd level, you can heighten your echo's fury. Whenever you take the Attack action, you can make one additional melee attack from the echo's position.</p>
          <p>You can use this feature a number of times equal to your Constitution modifier (a minimum of once). You regain all expended uses when you finish a long rest.</p>
        `,
        ability: '',
      },
      {
        name: 'Echo Avatar',
        level: 7,
        description: `
          <p>At 3rd level, you can heighten your echo's fury. Whenever you take the Attack action, you can make one additional melee attack from the echo's position.</p>
          <p>You can use this feature a number of times equal to your Constitution modifier (a minimum of once). You regain all expended uses when you finish a long rest.</p>
        `,
        ability: '',
      },
      {
        name: 'Shadow Martyr',
        level: 10,
        description: `
          <p>Starting at 10th level, you can make your echo throw itself in front of an attack directed at another creature that you can see. Before the attack roll is made, you can use your reaction to teleport the echo to an unoccupied space within 5 feet of the targeted creature. The attack roll that triggered the reaction is instead made against your echo.</p>
          <p>Once you use this feature, you can't use it again until you finish a short or long rest.</p>
        `,
        ability: '',
      },
      {
        name: 'Reclaim Potential',
        level: 15,
        description: `
          <p>By 15th level, you've learned to absorb the fleeting magic of your echo. When an echo of yours is destroyed by taking damage, you can gain a number of temporary hit points equal to 2d6 + your Constitution modifier, provided you don't already have temporary hit points.</p>
          <p>You can use this feature a number of times equal to your Constitution modifier (a minimum of once). You regain all expended uses when you finish a long rest.</p>
        `,
        ability: '',
      },
      {
        name: 'Legion of One',
        level: 15,
        description: `
          <p>At 18th level, you can use a bonus action to create two echos with your Manifest Echo feature, and these echoes can co-exist. If you try to create a third echo, the previous two echoes are destroyed. Anything you can do from one echo's position can be done from the other's instead.</p>
          <p>In addition, when you roll initiative and have no uses of your Unleash Incarnation feature left, you regain one use of that feature.</p>
        `,
        ability: '',
      },
    ],
  };

  // MONK

  private wayOfShadows: SubclassData = {
    title: 'Way of Shadows',
    description: `
      <p>Monks of the Way of Shadow follow a tradition that values stealth and subterfuge. These monks might be called ninjas or shadowdancers, and they serve as spies and assassins. Sometimes the members of a ninja monastery are family members, forming a clan sworn to secrecy about their arts and missions. Other monasteries are more like thieves' guilds, hiring out their services to nobles, rich merchants, or anyone else who can pay their fees. Regardless of their methods, the heads of these monasteries expect the unquestioning obedience of their students.</p>
    `,
    features: [
      {
        name: 'Shadow Arts',
        level: 3,
        description: `
          <p>Starting when you choose this tradition at 3rd level, you can use your ki to duplicate the effects of certain spells. As an action, you can spend 2 ki points to cast darkness, darkvision, pass without trace, or silence, without providing material components. Additionally, you gain the minor illusion cantrip if you don't already know it.</p>
        `,
        ability: '',
      },
      {
        name: 'Shadow Step',
        level: 6,
        description: `
          <p>At 6th level, you gain the ability to step from one shadow into another. When you are in dim light or darkness, as a bonus action you can teleport up to 60 feet to an unoccupied space you can see that is also in dim light or darkness. You then have advantage on the first melee attack you make before the end of the turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Cloak of Shadows',
        level: 11,
        description: `
          <p>By 11th level, you have learned to become one with the shadows. When you are in an area of dim light or darkness, you can use your action to become invisible. You remain invisible until you make an attack, cast a spell, or are in an area of bright light.</p>
        `,
        ability: '',
      },
      {
        name: 'Opportunist',
        level: 17,
        description: `
          <p>At 17th level, you can exploit a creature's momentary distraction when it is hit by an attack. Whenever a creature within 5 feet of you is hit by an attack made by a creature other than you, you can use your reaction to make a melee attack against that creature.</p>
        `,
        ability: '',
      },
    ],
  };

  // PALADIN

  private vengeance: SubclassData = {
    title: 'SChwur der Vergeltung',
    description: `
      <p>The Oath of Vengeance is a solemn commitment to punish those who have committed a grievous sin. When evil forces slaughter helpless villagers, when an entire people turns against the will of the gods, when a thieves' guild grows too violent and powerful, when a dragon rampages through the countryside—at times like these, paladins arise and swear an Oath of Vengeance to set right that which has gone wrong. To these paladins—sometimes called avengers or dark knights—their own purity is not as important as delivering justice.</p>
    `,
    features: [
      {
        name: 'Tenets of Vengeance',
        level: 3,
        description: `
          <p>The tenets of the Oath of Vengeance vary by paladin, but all the tenets revolve around punishing wrongdoers by any means necessary. Paladins who uphold these tenets are willing to sacrifice even their own righteousness to mete out justice upon those who do evil, so the paladins are often neutral or lawful neutral in alignment. The core principles of the tenets are brutally simple.</p>
          <p><strong><em>Fight the Greater Evil.</em></strong> Faced with a choice of fighting my sworn foes or combating a lesser evil, I choose the greater evil.</p>
          <p><strong><em>No Mercy for the Wicked.</em></strong> Ordinary foes might win my mercy, but my sworn enemies do not.</p>
          <p><strong><em>By Any Means Necessary.</em></strong> My qualms can't get in the way of exterminating my foes.</p>
          <p><strong><em>Restitution.</em></strong> If my foes wreak ruin on the world, it is because I failed to stop them. I must help those harmed by their misdeeds.</p>
          <h3 id="toc1"><span>Oath Spells</span></h3>
          <p>You gain oath spells at the paladin levels listed.</p>
        `,
      },
      {
        name: 'Channel Divinity: Abjure Enemy',
        level: 3,
        description: `
          <p>When you take this oath at 3rd level, you gain the following two Channel Divinity options.</p>
          <ul>
          <li><strong><em>Abjure Enemy.</em></strong> As an action, you present your holy symbol and speak a prayer of denunciation, using your Channel Divinity. Choose one creature within 60 feet of you that you can see. That creature must make a Wisdom saving throw, unless it is immune to being frightened. Fiends and undead have disadvantage on this saving throw.<br />
          <br />
          On a failed save, the creature is frightened for 1 minute or until it takes any damage. While frightened, the creature's speed is 0, and it can't benefit from any bonus to its speed.<br />
          <br />
          On a successful save, the creature's speed is halved for 1 minute or until the creature takes any damage.</li>
          </ul>
          <ul>
          <li><strong><em>Vow of Enmity.</em></strong> As a bonus action, you can utter a vow of enmity against a creature you can see within 10 feet of you, using your Channel Divinity. You gain advantage on attack rolls against the creature for 1 minute or until it drops to 0 hit points or falls unconscious.</li>
          </ul>
          `,
      },
      {
        name: 'Relentless Avenger',
        level: 7,
        description: `
          <p>By 7th level, your supernatural focus helps you close off a foe's retreat. When you hit a creature with an opportunity attack, you can move up to half your speed immediately after the attack and as part of the same reaction. This movement doesn't provoke opportunity attacks.</p>
        `,
      },
      {
        name: 'Soul of Vengeance',
        level: 15,
        description: `
          <p>Starting at 15th level, the authority with which you speak your Vow of Enmity gives you greater power over your foe. When a creature under the effect of your Vow of Enmity makes an attack, you can use your reaction to make a melee weapon attack against that creature if it is within range.</p>
        `,
        ability: '',
      },
      {
        name: 'Avenging Angel',
        level: 20,
        description: `
          <p>At 20th level, you can assume the form of an angelic avenger. Using your action, you undergo a transformation. For 1 hour, you gain the following benefits:</p>
          <ul>
          <li>Wings sprout from your back and grant you a flying speed of 60 feet.</li>
          </ul>
          <ul>
          <li>You emanate an aura of menace in a 30-foot radius. The first time any enemy creature enters the aura or starts its turn there during a battle, the creature must succeed on a Wisdom saving throw or become frightened of you for 1 minute or until it takes any damage. Attack rolls against the frightened creature have advantage.</li>
          </ul>
          <p>Once you use this feature, you can't use it again until you finish a long rest.</p>
          `,
        ability: '',
      },
    ],
  };

  // RANGER

  private beastMaster: SubclassData = {
    title: 'Beast Master',
    description: `
      <p>Rangers of the Beast Master archetype embrace the freedom of the wild, and they are driven by a bond with an animal companion who is as much a part of the ranger's life as the ranger is to the beast. Beast masters are skilled in survival, tracking, and hunting, and they are often found in the wild frontiers, plying their trade as guides, hunters, and scouts.</p>
    `,
    features: [
      {
        name: "Ranger's Companion",
        level: 3,
        description: `
          <p>At 3rd level, you gain a beast companion that accompanies you on your adventures and is trained to fight alongside you. Choose a beast that is no larger than Medium and that has a challenge rating of 1/4 or lower (Player's Handbook Appendix D presents statistics for the hawk, mastiff, and panther as examples). Add your proficiency bonus to the beast’s AC, attack rolls, and damage rolls, as well as to any saving throws and skills it is proficient in. Its hit point maximum equals its normal maximum or four times your ranger level, whichever is higher. Like any creature, the beast can spend Hit Dice during a short rest.</p>
          <p>The beast obeys your commands as best as it can. It takes its turn on your initiative. On your turn, you can verbally command the beast where to move (no action required by you). You can use your action to verbally command it to take the Attack, Dash, Disengage, or Help action. If you don’t issue a command, the beast takes the Dodge action. Once you have the Extra Attack feature, you can make one weapon attack yourself when you command the beast to take the Attack action. While traveling through your favored terrain with only the beast, you can move stealthily at a normal pace.</p>
          <p>If you are incapacitated or absent, the beast acts on its own, focusing on protecting you and itself. The beast never requires your command to use its reaction, such as when making an opportunity attack.</p>
          <p>If the beast dies, you can obtain another one by spending 8 hours magically bonding with another beast that isn’t hostile to you, either the same type of beast as before or a different one.</p>
        `,
        ability: '',
      },
      {
        mname: 'Primal Companion (Optional)',
        level: 3,
        description: `
          <p>This 3rd-level feature replaces the Ranger's Companion feature.</p>
          <p>You magically summon a primal beast, which draws strength from your bond with nature. The beast is friendly to you and your companions and obeys your commands. Choose its stat block-Beast of the Land, Beast of the Sea, or Beast of the Sky-which uses your proficiency bonus (PB) in several places. You also determine the kind of animal the beast is, choosing a kind appropriate for the stat block. Whatever kind you choose, the beast bears primal markings, indicating its mystical origin.</p>
          <p>In combat, the beast acts during your turn. It can move and use its reaction on its own, but the only action it takes is the Dodge action, unless you take a bonus action on your turn to command it to take another action. That action can be one in its stat block or some other action. You can also sacrifice one of your attacks when you take the Attack action to command the beast to take the Attack action. If<br />
          you are incapacitated, the beast can take any action of its choice, not just Dodge.</p>
          <p>If the beast has died within the last hour, you can use your action to touch it and expend a spell slot of 1st level or higher. The beast returns to life after 1 minute with all its hit points restored. When you finish a long rest, you can summon a different primal beast. The new beast appears in an unoccupied space within 5 feet of you, and you choose its stat block and appearance. If you already have a beast from this feature, it vanishes when the new beast appears. The beast also vanishes if you die.</p>
          <table 
          <tr>
          <th colspan="6">Beast of the Land</th>
          </tr>
          <tr>
          <td colspan="6"><em>Medium beast</em></td>
          </tr>
          <tr>
          <td colspan="6"><strong>Armor Class:</strong> 13 + PB (natural armor)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Hit Points:</strong> 5 + five times your ranger level (the beast has a number of Hit Dice [d8s] equal to your ranger level)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Speed:</strong> 40 ft., climb 40ft.</td>
          </tr>
          <tr>
          <th>STR</th>
          <th>DEX</th>
          <th>CON</th>
          <th>INT</th>
          <th>WIS</th>
          <th>CHA</th>
          </tr>
          <tr>
          <td>14 (+2)</td>
          <td>14 (+2)</td>
          <td>15 (+2)</td>
          <td>8 (−1)</td>
          <td>14 (+2)</td>
          <td>11 (+0)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Senses:</strong> darkvision 60 ft., passive Perception 12</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Languages:</strong> understands the languages you speak</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Challenge:</strong> &#8212;</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Proficiency Bonus (PB):</strong> equals your bonus</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Charge:</strong> If the beast moves at least 20 feet straight toward a target and then hits it with a maul attack on the same turn, the target takes an extra 1d6 slashing damage. If the target is a creature, it must succeed on a Strength saving throw against your spell save DC or be knocked prone.</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Primal Bond:</strong> You can add your proficiency bonus to any ability check or saving throw that the beast makes.</td>
          </tr>
          <tr>
          <th colspan="6">Actions</th>
          </tr>
          <tr>
          <td colspan="6"><strong><em>Maul.</em></strong> <em>Melee Weapon Attack:</em> your spell attack modifier to hit, reach 5 ft., one target. <em>Hit:</em> 1d8 + 2 + PB slashing damage.</td>
          </tr>
          </table>
          <table 
          <tr>
          <th colspan="6">Beast of the Sea</th>
          </tr>
          <tr>
          <td colspan="6"><em>Medium beast</em></td>
          </tr>
          <tr>
          <td colspan="6"><strong>Armor Class:</strong> 13 + PB (natural armor)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Hit Points:</strong> 5 + five times your ranger level (the beast has a number of Hit Dice [d8s] equal to your ranger level)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Speed:</strong> 5 ft., swim 60ft.</td>
          </tr>
          <tr>
          <th>STR</th>
          <th>DEX</th>
          <th>CON</th>
          <th>INT</th>
          <th>WIS</th>
          <th>CHA</th>
          </tr>
          <tr>
          <td>14 (+2)</td>
          <td>14 (+2)</td>
          <td>15 (+2)</td>
          <td>8 (−1)</td>
          <td>14 (+2)</td>
          <td>11 (+0)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Senses:</strong> darkvision 60 ft., passive Perception 12</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Languages:</strong> understands the languages you speak</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Challenge:</strong> &#8212;</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Proficiency Bonus (PB):</strong> equals your bonus</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Amphibious:</strong> The beast can breathe both air and water.</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Primal Bond:</strong> You can add your proficiency bonus to any ability check or saving throw that the beast makes.</td>
          </tr>
          <tr>
          <th colspan="6">Actions</th>
          </tr>
          <tr>
          <td colspan="6"><strong><em>Binding Strike.</em></strong> <em>Melee Weapon Attack:</em> your spell attack modifier to hit, reach 5 ft., one target. <em>Hit:</em> 1d6 + 2 + PB piercing or bludgeoning damage (your choice), and the target is grappled (escape DC equals your spell save DC). Until this grapple ends, the beast can't use this attack on another target.</td>
          </tr>
          </table>
          <table 
          <tr>
          <th colspan="6">Beast of the Sky</th>
          </tr>
          <tr>
          <td colspan="6"><em>Small beast</em></td>
          </tr>
          <tr>
          <td colspan="6"><strong>Armor Class:</strong> 13 + PB (natural armor)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Hit Points:</strong> 4 + four times your ranger level (the beast has a number of Hit Dice [d6s] equal to your ranger level)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Speed:</strong> 10 ft., fly 60ft.</td>
          </tr>
          <tr>
          <th>STR</th>
          <th>DEX</th>
          <th>CON</th>
          <th>INT</th>
          <th>WIS</th>
          <th>CHA</th>
          </tr>
          <tr>
          <td>6 (-2)</td>
          <td>16 (+3)</td>
          <td>13 (+1)</td>
          <td>8 (−1)</td>
          <td>14 (+2)</td>
          <td>11 (+0)</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Senses:</strong> darkvision 60 ft., passive Perception 12</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Languages:</strong> understands the languages you speak</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Challenge:</strong> &#8212;</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Proficiency Bonus (PB):</strong> equals your bonus</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Flyby:</strong> The beast doesn't provoke opportunity attacks when it flies out of an enemy's reach.</td>
          </tr>
          <tr>
          <td colspan="6"><strong>Primal Bond:</strong> You can add your proficiency bonus to any ability check or saving throw that the beast makes.</td>
          </tr>
          <tr>
          <th colspan="6">Actions</th>
          </tr>
          <tr>
          <td colspan="6"><strong><em>Shred.</em></strong> <em>Melee Weapon Attack:</em> your spell attack modifier to hit, reach 5 ft., one target. <em>Hit:</em> 1d4 + 3 + PB slashing damage.</td>
          </tr>
          </table>
       `,
        ability: '',
      },
      {
        name: 'Exceptional Training',
        level: 7,
        description: `
          <p>Beginning at 7th level, on any of your turns when your beast companion doesn't attack, you can use a bonus action to command the beast to take the Dash, Disengage, Dodge, or Help action on its turn.</p>
        `,
        ability: '',
      },
      {
        name: 'Bestial Fury',
        level: 11,
        description: `
          <p>Starting at 11th level, your beast companion's attacks are magical. Also, when you command the beast to take the Attack action, the beast can make two attacks, or it can take the Multiattack action if it has that action.</p>
        `,
      },
      {
        name: 'Share Spells',
        level: 15,
        description: `
          <p>Beginning at 15th level, when you cast a spell targeting yourself, you can also affect your beast companion with the spell if the beast is within 30 feet of you.</p>       
        `,
      },
    ],
  };

  // ROGUE

  // SORCERER

  // WARLOCK

  // WIZARD

  private notImplementedYet: any = {
    title: 'Not implemented yet',
    description: `
    This class is not implemented yet, please check back later.
    `,
    features: [],
  };
}
